"""
Extended tests for split_text_by_separator function covering additional edge cases.
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import (
    split_text_by_separator,
)

data_of_dash = {
    "kingdom-of italy (1789–1789)": ("kingdom of", "italy (1789–1789)"),
    "ministers-of foreign affairs of": ("ministers of", "foreign affairs of"),
    "ambassadors of federated states-of micronesia": ("ambassadors of federated states of", "micronesia"),
    "ambassadors of federated states of micronesia": ("", ""),
    "tourism in republic-of ireland": ("tourism in republic of", "ireland"),
}


data_of = {
    "ofyearsof of 16th ofcentury": ("ofyearsof of", "16th ofcentury"),
    "ambassadors of federated states of micronesia": ("ambassadors of", "federated states of micronesia"),
    "tourism in republic of ireland": ("tourism in republic of", "ireland"),
    "11th government of turkey": ("11th government of", "turkey"),
    "ambassadors of afghanistan": ("ambassadors of", "afghanistan"),
    "ambassadors of austria": ("ambassadors of", "austria"),
    "ambassadors of brazil": ("ambassadors of", "brazil"),
    "ambassadors of fiji": ("ambassadors of", "fiji"),
    "ambassadors of south africa": ("ambassadors of", "south africa"),
    "ambassadors of united states": ("ambassadors of", "united states"),
    "archaeology of europe": ("archaeology of", "europe"),
    "battles of napoleonic wars": ("battles of", "napoleonic wars"),
    "battles of vietnam war": ("battles of", "vietnam war"),
    "by province of saudi arabia": ("by province of", "saudi arabia"),
    "city of zagreb": ("city of", "zagreb"),
    "companies of georgia (country)": ("companies of", "georgia (country)"),
    "companies of southeast asia": ("companies of", "southeast asia"),
    "croatian war of independence": ("croatian war of", "independence"),
    "demographics of united states": ("demographics of", "united states"),
    "economy of united states": ("economy of", "united states"),
    "environment of united states": ("environment of", "united states"),
    "fauna of vermont": ("fauna of", "vermont"),
    "federalist party members of united states house-of-representatives": (
        "federalist party members of",
        "united states house-of-representatives",
    ),
    "fishes of europe": ("fishes of", "europe"),
    "former colleges of university of london": ("former colleges of", "university of london"),
    "french invasion of egypt and syria": ("french invasion of", "egypt and syria"),
    "geography of kansas": ("geography of", "kansas"),
    "geography of united states": ("geography of", "united states"),
    "german novels of 20th century": ("german novels of", "20th century"),
    "government of burkina faso": ("government of", "burkina faso"),
    "heads of universities and colleges": ("heads of", "universities and colleges"),
    "images of united states": ("images of", "united states"),
    "impact of covid-19 pandemic": ("impact of", "covid-19 pandemic"),
    "indigenous peoples of americas": ("indigenous peoples of", "americas"),
    "installations of united states air force": ("installations of", "united states air force"),
    "insular areas of united states": ("insular areas of", "united states"),
    "know-nothing members of united states house-of-representatives": (
        "know-nothing members of",
        "united states house-of-representatives",
    ),
    "lists of 1789 films": ("lists of", "1789 films"),
    "lists of ambassadors": ("lists of", "ambassadors"),
    "lists of bosnia and herzegovina people": ("lists of", "bosnia and herzegovina people"),
    "lists of british television series characters": ("lists of", "british television series characters"),
    "lists of buildings and structures": ("lists of", "buildings and structures"),
    "lists of country subdivisions": ("lists of", "country subdivisions"),
    "lists of football players": ("lists of", "football players"),
    "lists of legislators": ("lists of", "legislators"),
    "lists of mass media": ("lists of", "mass media"),
    "lists of mayors of places": ("lists of", "mayors of places"),
    "lists of roads": ("lists of", "roads"),
    "lists of television characters": ("lists of", "television characters"),
    "lists of universities and colleges": ("lists of", "universities and colleges"),
    "members of maine legislature": ("members of", "maine legislature"),
    "military operations of american civil war": ("military operations of", "american civil war"),
    "military operations of syrian civil war": ("military operations of", "syrian civil war"),
    "military operations of war": ("military operations of", "war"),
    "non-profit organizations of brazil": ("non-profit organizations of", "brazil"),
    "non-profit organizations of canada": ("non-profit organizations of", "canada"),
    "non-profit organizations of chile": ("non-profit organizations of", "chile"),
    "non-profit organizations of colombia": ("non-profit organizations of", "colombia"),
    "non-profit organizations of costa rica": ("non-profit organizations of", "costa rica"),
    "non-profit organizations of united kingdom": ("non-profit organizations of", "united kingdom"),
    "non-profit organizations of united states": ("non-profit organizations of", "united states"),
    "northern ireland of canadian descent": ("northern ireland of", "canadian descent"),
    "order of british empire": ("order of", "british empire"),
    "parliament of barbados": ("parliament of", "barbados"),
    "parliament of england 1789": ("parliament of", "england 1789"),
    "parliament of great britain": ("parliament of", "great britain"),
    "parliament of ireland 1550": ("parliament of", "ireland 1550"),
    "parliament of northern ireland 1789–1789": ("parliament of", "northern ireland 1789–1789"),
    "parliament of united kingdom": ("parliament of", "united kingdom"),
    "people accused of lèse majesté": ("people accused of", "lèse majesté"),
    "people associated with former colleges of university of london": (
        "people associated with former colleges of",
        "university of london",
    ),
    "people of dutch empire": ("people of", "dutch empire"),
    "permanent representatives of bahrain": ("permanent representatives of", "bahrain"),
    "permanent representatives of jamaica": ("permanent representatives of", "jamaica"),
    "permanent representatives of kazakhstan": ("permanent representatives of", "kazakhstan"),
    "permanent representatives of kyrgyzstan": ("permanent representatives of", "kyrgyzstan"),
    "persecution of lgbtq people": ("persecution of", "lgbtq people"),
    "politics of united states": ("politics of", "united states"),
    "prime ministers of japan": ("prime ministers of", "japan"),
    "prime ministers of malaysia": ("prime ministers of", "malaysia"),
    "prime ministers of ukraine": ("prime ministers of", "ukraine"),
    "protected areas of georgia (u.s. state)": ("protected areas of", "georgia (u.s. state)"),
    "protected areas of united states": ("protected areas of", "united states"),
    "rivers of united states": ("rivers of", "united states"),
    "society of united states": ("society of", "united states"),
    "tanks of united states": ("tanks of", "united states"),
    "the parliament of united kingdom": ("the parliament of", "united kingdom"),
    "university of galway": ("university of", "galway"),
    "university of sheffield": ("university of", "sheffield"),
    "verkhovna rada of ukrainian soviet socialist republic": (
        "verkhovna rada of",
        "ukrainian soviet socialist republic",
    ),
    "victims of aviation accidents or incidents": ("victims of", "aviation accidents or incidents"),
    "water of coquimbo region": ("water of", "coquimbo region"),
    "water of hambantota district": ("water of", "hambantota district"),
    "water of matale district": ("water of", "matale district"),
    "water of novosibirsk oblast": ("water of", "novosibirsk oblast"),
    "water of wilkes land": ("water of", "wilkes land"),
    "whig party members of united states house-of-representatives": (
        "whig party members of",
        "united states house-of-representatives",
    ),
    "years of 17th century": ("years of", "17th century"),
    "years of 18th century": ("years of", "18th century"),
    "years of 19th century": ("years of", "19th century"),
    "years of 20th century": ("years of", "20th century"),
    "years of 21st century": ("years of", "21st century"),
}


data_about = {
    "books about automobiles": ("books", "automobiles"),
    "books about politics": ("books", "politics"),
    "documentary films about the 2011 tōhoku earthquake and tsunami": (
        "documentary films",
        "the 2011 tōhoku earthquake and tsunami",
    ),
    "films about automobiles": ("films", "automobiles"),
    "films about olympic boxing": ("films", "olympic boxing"),
    "films about olympic figure skating": ("films", "olympic figure skating"),
    "films about olympic gymnastics": ("films", "olympic gymnastics"),
    "films about olympic skiing": ("films", "olympic skiing"),
    "films about olympic track and field": ("films", "olympic track and field"),
    "films about the olympic games": ("films", "the olympic games"),
    "films basedon non-fiction books about organized crime": ("films basedon non-fiction books", "organized crime"),
    "non-fiction books about acting": ("non-fiction books", "acting"),
    "non-fiction books about dogs": ("non-fiction books", "dogs"),
    "non-fiction books about the royal air force": ("non-fiction books", "the royal air force"),
    "non-fiction books about the sicilian mafia": ("non-fiction books", "the sicilian mafia"),
    "non-fiction books about the united states air force": ("non-fiction books", "the united states air force"),
    "non-fiction books about the united states navy": ("non-fiction books", "the united states navy"),
    "non-fiction novels about murders": ("non-fiction novels", "murders"),
    "non-fiction writers about organized crime": ("non-fiction writers", "organized crime"),
    "songs about automobiles": ("songs", "automobiles"),
    "songs about busan": ("songs", "busan"),
    "video games about diseases": ("video games", "diseases"),
    "video games about slavery": ("video games", "slavery"),
    "works about automobiles": ("works", "automobiles"),
}


data_by = {
    "-endings by year": ("-endings", "by year"),
    "1420 by country": ("1420", "by country"),
    "actors by religion": ("actors", "by religion"),
    "australian open by year – wheelchair ": ("australian open", "by year – wheelchair"),
    "british television series characters by series": ("british television series characters", "by series"),
    "by period by state": ("by period", "by state"),
    "european rugby union by country": ("european rugby union", "by country"),
    "football players by national team": ("football players", "by national team"),
    "french open by year – wheelchair ": ("french open", "by year – wheelchair"),
    "monarchs by country": ("monarchs", "by country"),
    "non-fiction writers by nationality": ("non-fiction writers", "by nationality"),
    "people by religion": ("people", "by religion"),
    "people from westchester county, new york by place holder": (
        "people from westchester county, new york",
        "by place holder",
    ),
    "television characters by series": ("television characters", "by series"),
    "television plays directed by william sterling (director)": (
        "television plays directed",
        "by william sterling (director)",
    ),
    "the united states by state": ("the united states", "by state"),
    "united states by state": ("united states", "by state"),
    "wheelchair sports competitors by nationality": ("wheelchair sports competitors", "by nationality"),
    "wheelchair track and field athletes by nationality": ("wheelchair track and field athletes", "by nationality"),
    "wheelchair users by nationality": ("wheelchair users", "by nationality"),
    "wimbledon championship by year – wheelchair ": ("wimbledon championship", "by year – wheelchair"),
}


data_from = {
    "actresses from ohio": ("actresses", "ohio"),
    "emigrants from the russian empire": ("emigrants", "the russian empire"),
    "expatriates from northern ireland": ("expatriates", "northern ireland"),
    "male actors from the west midlands (county)": ("male actors", "the west midlands (county)"),
    "non-fiction writers from northern ireland": ("non-fiction writers", "northern ireland"),
    "non-fiction writers from the russian empire": ("non-fiction writers", "the russian empire"),
    "people from al-andalus": ("people", "al-andalus"),
    "people from bangkok": ("people", "bangkok"),
    "people from batangas": ("people", "batangas"),
    "people from east lothian": ("people", "east lothian"),
    "people from west sumatra": ("people", "west sumatra"),
    "people from westchester county, new york": ("people", "westchester county, new york"),
    "rugby union players from west yorkshire": ("rugby union players", "west yorkshire"),
    "united kingdom from aden": ("united kingdom", "aden"),
    "united states house-of-representatives from missouri territory": (
        "united states house-of-representatives",
        "missouri territory",
    ),
    "wheelchair users from georgia (country)": ("wheelchair users", "georgia (country)"),
}


data_in = {
    "100 metres in the african championships in athletics": ("100 metres", "the african championships in athletics"),
    "100 metres in the iaaf world youth championships in athletics": (
        "100 metres",
        "the iaaf world youth championships in athletics",
    ),
    "100 metres in the world para athletics championships": ("100 metres", "the world para athletics championships"),
    "1550 in antigua and barbuda": ("1550", "antigua and barbuda"),
    "1550 in mexico": ("1550", "mexico"),
    "1550 in south america": ("1550", "south america"),
    "1550 in sports": ("1550", "sports"),
    "1550 in thailand": ("1550", "thailand"),
    "1550 in women's sport": ("1550", "women's sport"),
    "1550s in asia": ("1550s", "asia"),
    "1789 crimes in africa": ("1789 crimes", "africa"),
    "1789 elections in the united states": ("1789 elections", "the united states"),
    "1789 establishments in india": ("1789 establishments", "india"),
    "1789 in asian sport": ("1789", "asian sport"),
    "1789 in brazilian sport": ("1789", "brazilian sport"),
    "1789 in men's football": ("1789", "men's football"),
    "1789 in north america": ("1789", "north america"),
    "1789 in south america": ("1789", "south america"),
    "1789 in south american football": ("1789", "south american football"),
    "1789 in the united kingdom": ("1789", "the united kingdom"),
    "1789 in women's sport": ("1789", "women's sport"),
    "1789 in youth football": ("1789", "youth football"),
    "1994–95 in european rugby union": ("1994–95", "european rugby union"),
    "20th century in iraq": ("20th century", "iraq"),
    "anglican bishops in asia": ("anglican bishops", "asia"),
    "baseball playerss in florida": ("baseball playerss", "florida"),
    "baseball playerss in south korea": ("baseball playerss", "south korea"),
    "basketball playerss in lebanon": ("basketball playerss", "lebanon"),
    "bridges in france": ("bridges", "france"),
    "bridges in wales": ("bridges", "wales"),
    "buildings and structures in africa": ("buildings and structures", "africa"),
    "buildings and structures in georgia (u.s. state)": ("buildings and structures", "georgia (u.s. state)"),
    "buildings and structures in idaho": ("buildings and structures", "idaho"),
    "buildings and structures in prince edward island": ("buildings and structures", "prince edward island"),
    "buildings and structures in the united states": ("buildings and structures", "the united states"),
    "burials in washington (state)": ("burials", "washington (state)"),
    "by city in colombia": ("by city", "colombia"),
    "by city in northern-ireland": ("by city", "northern-ireland"),
    "by county in taiwan": ("by county", "taiwan"),
    "by educational institution in derbyshire": ("by educational institution", "derbyshire"),
    "by league in the united states": ("by league", "the united states"),
    "by newspaper in california": ("by newspaper", "california"),
    "by state in the united states": ("by state", "the united states"),
    "by team in the united states": ("by team", "the united states"),
    "by university or college in beijing": ("by university or college", "beijing"),
    "centuries in the united states": ("centuries", "the united states"),
    "christianity in the united states": ("christianity", "the united states"),
    "college men's wheelchair basketball teams in the united states": (
        "college men's wheelchair basketball teams",
        "the united states",
    ),
    "college women's wheelchair basketball teams in the united states": (
        "college women's wheelchair basketball teams",
        "the united states",
    ),
    "communications in the united states": ("communications", "the united states"),
    "crimes in peru": ("crimes", "peru"),
    "crimes in the united states": ("crimes", "the united states"),
    "decades in the united states": ("decades", "the united states"),
    "disasters in the united states": ("disasters", "the united states"),
    "disestablishments in ecuador": ("disestablishments", "ecuador"),
    "disestablishments in georgia (u.s. state)": ("disestablishments", "georgia (u.s. state)"),
    "disestablishments in yugoslavia": ("disestablishments", "yugoslavia"),
    "education in the united states": ("education", "the united states"),
    "establishments in guernsey": ("establishments", "guernsey"),
    "establishments in southeast asia": ("establishments", "southeast asia"),
    "ethnic groups in china": ("ethnic groups", "china"),
    "field hockey playerss in germany": ("field hockey playerss", "germany"),
    "food and drink in europe": ("food and drink", "europe"),
    "forts in the united states": ("forts", "the united states"),
    "health in the united states": ("health", "the united states"),
    "high schools in india": ("high schools", "india"),
    "historic districts in massachusetts": ("historic districts", "massachusetts"),
    "historic sites in the united states": ("historic sites", "the united states"),
    "historic trails and roads in the united states": ("historic trails and roads", "the united states"),
    "iaaf world youth championships in athletics": ("iaaf world youth championships", "athletics"),
    "landmarks in the united states": ("landmarks", "the united states"),
    "local politicians in the united kingdom": ("local politicians", "the united kingdom"),
    "manufacturing in the united states": ("manufacturing", "the united states"),
    "mass media in bosnia and herzegovina": ("mass media", "bosnia and herzegovina"),
    "mass media in morocco": ("mass media", "morocco"),
    "metres in the african championships in athletics": ("metres", "the african championships in athletics"),
    "metres in the iaaf world youth championships in athletics": (
        "metres",
        "the iaaf world youth championships in athletics",
    ),
    "metres in the world para athletics championships": ("metres", "the world para athletics championships"),
    "military operations of war in afghanistan (1789–1789)": ("military operations of war", "afghanistan (1789–1789)"),
    "national-register-of-historic-places in north carolina": (
        "national-register-of-historic-places",
        "north carolina",
    ),
    "nations in the summer olympics": ("nations", "the summer olympics"),
    "nature reserves in the united states": ("nature reserves", "the united states"),
    "netball in north america": ("netball", "north america"),
    "parks in south america": ("parks", "south america"),
    "people accused of lèse majesté in thailand since 2020": ("people accused of lèse majesté", "thailand since 2020"),
    "people accused of lèse majesté in thailand": ("people accused of lèse majesté", "thailand"),
    "populated places in latvia": ("populated places", "latvia"),
    "populated places in portugal": ("populated places", "portugal"),
    "populated places in uruguay": ("populated places", "uruguay"),
    "rail transport in sri lanka": ("rail transport", "sri lanka"),
    "railway stations in albania": ("railway stations", "albania"),
    "railway stations in austria": ("railway stations", "austria"),
    "railway stations in the united states": ("railway stations", "the united states"),
    "religion in the united states": ("religion", "the united states"),
    "riots and civil disorder in the united states": ("riots and civil disorder", "the united states"),
    "road incident deaths in the united states": ("road incident deaths", "the united states"),
    "saint kitts and nevis in the summer olympics": ("saint kitts and nevis", "the summer olympics"),
    "science and technology in the united states": ("science and technology", "the united states"),
    "shopping malls in ukraine": ("shopping malls", "ukraine"),
    "skyscrapers in the united arab emirates": ("skyscrapers", "the united arab emirates"),
    "slavery in the united states": ("slavery", "the united states"),
    "sport in the ottoman empire": ("sport", "the ottoman empire"),
    "sports governing bodies in north america": ("sports governing bodies", "north america"),
    "sports venues in australia": ("sports venues", "australia"),
    "sports-people in ireland": ("sports-people", "ireland"),
    "sports-people in västmanland county": ("sports-people", "västmanland county"),
    "synagogues in switzerland": ("synagogues", "switzerland"),
    "television plays filmed in brisbane": ("television plays filmed", "brisbane"),
    "the iaaf world youth championships in athletics": ("the iaaf world youth championships", "athletics"),
    "tourism in the united kingdom": ("tourism", "the united kingdom"),
    "tourist attractions in the united states": ("tourist attractions", "the united states"),
    "trade unions in the caribbean": ("trade unions", "the caribbean"),
    "transport infrastructure in south america": ("transport infrastructure", "south america"),
    "transportation buildings and structures in new hampshire": (
        "transportation buildings and structures",
        "new hampshire",
    ),
    "transportation in the united states": ("transportation", "the united states"),
    "unincorporated communities in alaska": ("unincorporated communities", "alaska"),
    "united nations in geneva": ("united nations", "geneva"),
    "universities and colleges in andhra pradesh": ("universities and colleges", "andhra pradesh"),
    "universities and colleges in ghana": ("universities and colleges", "ghana"),
    "universities and colleges in texas": ("universities and colleges", "texas"),
    "universities and colleges in ukraine": ("universities and colleges", "ukraine"),
    "universities and colleges in uruguay": ("universities and colleges", "uruguay"),
    "villages in north macedonia": ("villages", "north macedonia"),
    "volleyball competitions in asia": ("volleyball competitions", "asia"),
    "wheelchair basketball in 2020 asean para games": ("wheelchair basketball", "2020 asean para games"),
    "wheelchair basketball in the asean para games": ("wheelchair basketball", "the asean para games"),
    "wheelchair basketball playerss in turkey": ("wheelchair basketball playerss", "turkey"),
    "wheelchair fencing in 2020 asean para games": ("wheelchair fencing", "2020 asean para games"),
    "wheelchair fencing in the asean para games": ("wheelchair fencing", "the asean para games"),
    "wheelchair tennis in 2020 asean para games": ("wheelchair tennis", "2020 asean para games"),
    "wheelchair tennis in the asean para games": ("wheelchair tennis", "the asean para games"),
    "women's footballers in ireland": ("women's footballers", "ireland"),
    "years in the united states": ("years", "the united states"),
}

data_on = {
    "agricultural buildings and structures on the-national-register-of-historic-places": (
        "agricultural buildings and structures",
        "the-national-register-of-historic-places",
    ),
    "attacks on buildings and structures": ("attacks", "buildings and structures"),
    "attacks on diplomatic missions": ("attacks", "diplomatic missions"),
    "attacks on military installations": ("attacks", "military installations"),
    "bank buildings on the-national-register-of-historic-places": (
        "bank buildings",
        "the-national-register-of-historic-places",
    ),
    "buildings and structures on the-national-register-of-historic-places": (
        "buildings and structures",
        "the-national-register-of-historic-places",
    ),
    "clubhouses on the-national-register-of-historic-places": (
        "clubhouses",
        "the-national-register-of-historic-places",
    ),
    "courthouses on the-national-register-of-historic-places": (
        "courthouses",
        "the-national-register-of-historic-places",
    ),
    "military facilities on the-national-register-of-historic-places": (
        "military facilities",
        "the-national-register-of-historic-places",
    ),
    "opera houses on the-national-register-of-historic-places": (
        "opera houses",
        "the-national-register-of-historic-places",
    ),
    "railway stations on the-national-register-of-historic-places": (
        "railway stations",
        "the-national-register-of-historic-places",
    ),
}


data_to = {
    "ambassadors to the ottoman empire": ("ambassadors", "the ottoman empire"),
    "immigrants to new zealand": ("immigrants", "new zealand"),
    "immigration to europe": ("immigration", "europe"),
    "immigration to new zealand": ("immigration", "new zealand"),
    "immigration to the united states": ("immigration", "the united states"),
    "italian defectors to the soviet union": ("italian defectors", "the soviet union"),
    "treaties extended to curaçao": ("treaties extended", "curaçao"),
    "united states navy to the royal navy": ("united states navy", "the royal navy"),
}


data_based_in = {
    "organizations based in argentina": ("organizations", "argentina"),
    "organizations based in australia": ("organizations", "australia"),
    "organizations based in brazil": ("organizations", "brazil"),
    "organizations based in canada": ("organizations", "canada"),
    "organizations based in gabon": ("organizations", "gabon"),
}


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_of_dash.items(), ids=data_of_dash.keys())
def test_data_of_dash(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator="-of ", country=category)

    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_about.items(), ids=data_about.keys())
def test_data_about(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" about ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_by.items(), ids=data_by.keys())
def test_data_by(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" by ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_from.items(), ids=data_from.keys())
def test_data_from(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" from ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_in.items(), ids=data_in.keys())
def test_data_in(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" in ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_of.items(), ids=data_of.keys())
def test_data_of(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" of ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_on.items(), ids=data_on.keys())
def test_data_on(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" on ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_to.items(), ids=data_to.keys())
def test_data_to(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" to ", country=category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", data_based_in.items(), ids=data_based_in.keys())
def test_split_text_by_separator(category: str, expected: tuple[str, str]) -> None:
    result: tuple[str, str] = split_text_by_separator(separator=" based in ", country=category)
    assert result == expected



import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data = {
    "1650s crimes": "جرائم عقد 1650",
    "1650s disasters": "كوارث عقد 1650",
    "1650s disestablishments": "انحلالات عقد 1650",
    "1650s establishments": "تأسيسات عقد 1650",
    "1st millennium bc establishments": "تأسيسات الألفية 1 ق م",
    "1st millennium disestablishments": "انحلالات الألفية 1",
    "20th century attacks": "هجمات القرن 20",
    "20th century clergy": "رجال دين في القرن 20",
    "20th century lawyers": "محامون في القرن 20",
    "20th century mathematicians": "رياضياتيون في القرن 20",
    "20th century north american people": "أمريكيون شماليون في القرن 20",
    "20th century norwegian people": "نرويجيون في القرن 20",
    "20th century people": "أشخاص في القرن 20",
    "20th century philosophers": "فلاسفة في القرن 20",
    "20th century photographers": "مصورون في القرن 20",
    "20th century roman catholic bishops": "أساقفة كاثوليك رومان في القرن 20",
    "20th century romanian people": "رومان في القرن 20",
    "march 1650 crimes": "جرائم مارس 1650",
    "september 1650 crimes": "جرائم سبتمبر 1650",
}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_event2_fast(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("fast_data", fast_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/env python3
"""
أداة لتحليل الاختبارات المكررة في ملفات tests/event_lists

هذا السكريبت يقوم بـ:
1. تحليل جميع ملفات Python في tests/event_lists
2. استخراج أزواج المفاتيح-القيم من القواميس
3. حساب عدد التكرارات لكل زوج
4. عرض النتائج مع إمكانية إزالة المكررات
"""

import ast
import json
import os
from collections import defaultdict
from pathlib import Path
from typing import Dict, List, Set, Tuple


class DuplicateTestAnalyzer:
    """محلل الاختبارات المكررة"""

    def __init__(self, base_path: str):
        """
        تهيئة المحلل

        Args:
            base_path: المسار الأساسي لمجلد tests/event_lists
        """
        self.base_path = Path(base_path)
        # تخزين الأزواج: {(key, value): [(file_path, dict_name, line_number), ...]}
        self.test_pairs: Dict[Tuple[str, str], List[Tuple[str, str, int]]] = defaultdict(list)
        # تخزين محتوى الملفات
        self.file_contents: Dict[str, List[str]] = {}

    def extract_dict_from_node(self, node: ast.Dict, file_path: str, dict_name: str = "unknown") -> None:
        """
        استخراج أزواج المفاتيح-القيم من عقدة قاموس AST

        Args:
            node: عقدة القاموس في AST
            file_path: مسار الملف
            dict_name: اسم القاموس
        """
        for key_node, value_node in zip(node.keys, node.values):
            # تجاهل العناصر None (في حالة dictionary unpacking)
            if key_node is None or value_node is None:
                continue

            # استخراج القيم الحرفية فقط (strings)
            if isinstance(key_node, ast.Constant) and isinstance(value_node, ast.Constant):
                if isinstance(key_node.value, str) and isinstance(value_node.value, str):
                    key = key_node.value
                    value = value_node.value
                    line_number = key_node.lineno

                    # تخزين الزوج مع معلومات موقعه
                    self.test_pairs[(key, value)].append((file_path, dict_name, line_number))

    def analyze_file(self, file_path: Path) -> None:
        """
        تحليل ملف Python واحد

        Args:
            file_path: مسار الملف
        """
        try:
            with open(file_path, "r", encoding="utf-8") as f:
                content = f.read()
                lines = content.splitlines()

            # حفظ محتوى الملف للاستخدام لاحقاً
            self.file_contents[str(file_path)] = lines

            # تحليل الملف باستخدام AST
            tree = ast.parse(content, filename=str(file_path))

            # تتبع العقد التي تم معالجتها لتجنب التكرار
            processed_nodes = set()

            # البحث عن جميع القواميس في الملف
            for node in ast.walk(tree):
                # البحث عن تعيينات القواميس (مثل: data1 = {...})
                if isinstance(node, ast.Assign):
                    for target in node.targets:
                        if isinstance(target, ast.Name) and isinstance(node.value, ast.Dict):
                            # استخدام id العقدة لتجنب المعالجة المكررة
                            if id(node.value) not in processed_nodes:
                                dict_name = target.id
                                self.extract_dict_from_node(node.value, str(file_path), dict_name)
                                processed_nodes.add(id(node.value))

        except Exception as e:
            print(f"⚠️  خطأ في تحليل الملف {file_path}: {e}")

    def scan_directory(self) -> None:
        """مسح جميع ملفات Python في المجلد"""
        print(f"🔍 جاري مسح المجلد: {self.base_path}")

        # البحث عن جميع ملفات .py
        python_files = list(self.base_path.rglob("*.py"))

        # استبعاد ملفات __pycache__ و __init__.py
        python_files = [f for f in python_files if "__pycache__" not in str(f) and f.name != "__init__.py"]

        print(f"📁 تم العثور على {len(python_files)} ملف Python")

        for file_path in python_files:
            self.analyze_file(file_path)

    def get_duplicates(self) -> Dict[Tuple[str, str], List[Tuple[str, str, int]]]:
        """
        الحصول على الأزواج المكررة فقط

        Returns:
            قاموس بالأزواج المكررة ومواقعها
        """
        return {pair: locations for pair, locations in self.test_pairs.items() if len(locations) > 1}

    def print_statistics(self) -> None:
        """طباعة إحصائيات التحليل"""
        duplicates = self.get_duplicates()
        total_pairs = len(self.test_pairs)
        duplicate_pairs = len(duplicates)

        # حساب إجمالي التكرارات
        total_occurrences = sum(len(locations) for locations in duplicates.values())

        print("\n" + "=" * 80)
        print("📊 إحصائيات التحليل")
        print("=" * 80)
        print(f"إجمالي الأزواج الفريدة: {total_pairs:,}")
        print(f"عدد الأزواج المكررة: {duplicate_pairs:,}")
        print(f"إجمالي التكرارات: {total_occurrences:,}")
        if total_pairs > 0:
            print(f"نسبة التكرار: {(duplicate_pairs/total_pairs*100):.2f}%")
        print("=" * 80 + "\n")

    def print_duplicates(self, limit: int = 20) -> None:
        """
        طباعة الأزواج المكررة

        Args:
            limit: الحد الأقصى لعدد الأزواج المعروضة
        """
        duplicates = self.get_duplicates()

        if not duplicates:
            print("✅ لا توجد اختبارات مكررة!")
            return

        # ترتيب حسب عدد التكرارات (الأكثر تكراراً أولاً)
        sorted_duplicates = sorted(duplicates.items(), key=lambda x: len(x[1]), reverse=True)

        print(f"\n🔍 عرض أول {min(limit, len(sorted_duplicates))} زوج مكرر:\n")

        for idx, ((key, value), locations) in enumerate(sorted_duplicates[:limit], 1):
            print(f"\n{idx}. تكرر {len(locations)} مرة:")
            print(f"   المفتاح: {key}")
            print(f"   القيمة: {value}")
            print(f"   المواقع:")

            for file_path, dict_name, line_num in locations:
                rel_path = Path(file_path).relative_to(self.base_path.parent)
                print(f"      - {rel_path} (القاموس: {dict_name}, السطر: {line_num})")

        if len(sorted_duplicates) > limit:
            print(f"\n... و {len(sorted_duplicates) - limit} زوج مكرر آخر")

    def save_report(self, output_file: str = "duplicate_tests_report.json") -> None:
        """
        حفظ تقرير مفصل بصيغة JSON

        Args:
            output_file: اسم ملف التقرير
        """
        duplicates = self.get_duplicates()

        report = {
            "summary": {
                "total_unique_pairs": len(self.test_pairs),
                "duplicate_pairs": len(duplicates),
                "total_occurrences": sum(len(locs) for locs in duplicates.values()),
            },
            "duplicates": [],
        }

        for (key, value), locations in sorted(duplicates.items(), key=lambda x: len(x[1]), reverse=True):
            report["duplicates"].append(
                {
                    "key": key,
                    "value": value,
                    "count": len(locations),
                    "locations": [
                        {"file": str(Path(fp).relative_to(self.base_path.parent)), "dict_name": dn, "line": ln}
                        for fp, dn, ln in locations
                    ],
                }
            )

        with open(output_file, "w", encoding="utf-8") as f:
            json.dump(report, f, ensure_ascii=False, indent=2)

        print(f"\n💾 تم حفظ التقرير في: {output_file}")

    def remove_duplicates_interactive(self) -> None:
        """إزالة المكررات بشكل تفاعلي"""
        duplicates = self.get_duplicates()

        if not duplicates:
            print("✅ لا توجد اختبارات مكررة للإزالة!")
            return

        print("\n" + "=" * 80)
        print("🗑️  وضع إزالة المكررات")
        print("=" * 80)
        print("سيتم الاحتفاظ بأول ظهور لكل زوج وإزالة التكرارات الأخرى")

        response = input("\nهل تريد المتابعة؟ (نعم/لا): ").strip().lower()

        if response not in ["نعم", "yes", "y", "ن"]:
            print("❌ تم الإلغاء")
            return

        # تجميع الأسطر المراد حذفها حسب الملف
        lines_to_remove: Dict[str, Set[int]] = defaultdict(set)

        for (key, value), locations in duplicates.items():
            # الاحتفاظ بأول ظهور، حذف الباقي
            for file_path, dict_name, line_num in locations[1:]:
                lines_to_remove[file_path].add(line_num)

        # إزالة الأسطر من كل ملف
        files_modified = 0
        lines_removed = 0

        for file_path, line_numbers in lines_to_remove.items():
            try:
                lines = self.file_contents[file_path]

                # إنشاء محتوى جديد بدون الأسطر المكررة
                new_lines = []
                for idx, line in enumerate(lines, 1):
                    if idx not in line_numbers:
                        new_lines.append(line)
                    else:
                        lines_removed += 1

                # كتابة الملف المحدث
                with open(file_path, "w", encoding="utf-8") as f:
                    f.write("\n".join(new_lines))
                    if new_lines and not new_lines[-1].endswith("\n"):
                        f.write("\n")

                files_modified += 1
                rel_path = Path(file_path).relative_to(self.base_path.parent)
                print(f"✅ تم تحديث: {rel_path} (حذف {len(line_numbers)} سطر)")

            except Exception as e:
                print(f"❌ خطأ في تحديث {file_path}: {e}")

        print("\n✨ تم الانتهاء!")
        print(f"   - الملفات المعدلة: {files_modified}")
        print(f"   - الأسطر المحذوفة: {lines_removed}")


def main():
    """الدالة الرئيسية"""
    # المسار الأساسي
    base_path = Path(__file__).parent / "tests"

    if not base_path.exists():
        print(f"❌ المسار غير موجود: {base_path}")
        return

    # إنشاء المحلل
    analyzer = DuplicateTestAnalyzer(str(base_path))

    # مسح الملفات
    analyzer.scan_directory()

    # عرض الإحصائيات
    analyzer.print_statistics()

    # عرض المكررات
    analyzer.print_duplicates(limit=30)

    # حفظ التقرير
    analyzer.save_report()

    # سؤال المستخدم عن إزالة المكررات
    print("\n" + "=" * 80)
    response = input("هل تريد إزالة الاختبارات المكررة؟ (نعم/لا): ").strip().lower()

    if response in ["نعم", "yes", "y", "ن"]:
        analyzer.remove_duplicates_interactive()
    else:
        print("✅ تم الاحتفاظ بالملفات كما هي")


if __name__ == "__main__":
    main()



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data = {
    "yemeni sports": "ألعاب رياضية يمنية",
    "yemeni sport": "رياضة يمنية",
    "yemeni buildings": "مباني يمنية",
    "yemeni companies": "شركات يمنية",
    "yemeni elections": "انتخابات يمنية",
    "yemeni songs": "أغاني يمنية",
    "yemeni television series": "مسلسلات تلفزيونية يمنية",
    "yemeni sports-events": "أحداث رياضية يمنية",
    "yemeni music": "موسيقى يمنية",
    "yemeni clubs": "أندية يمنية",
    "yemeni works": "أعمال يمنية",
    "yemeni organizations": "منظمات يمنية",
    "yemeni crimes": "جرائم يمنية",
    "yemeni islands": "جزر يمنية",
    "yemeni competitions": "منافسات يمنية",
    "yemeni novels": "روايات يمنية",
    "yemeni culture": "ثقافة يمنية",
    "yemeni media": "وسائل إعلام يمنية",
    "yemeni organisations": "منظمات يمنية",
    "yemeni architecture": "عمارة يمنية",
    "yemeni championships": "بطولات يمنية",
    "yemeni radio": "راديو يمنية",
    "yemeni awards": "جوائز يمنية",
    "yemeni comedy": "كوميديا يمنية",
    "yemeni festivals": "مهرجانات يمنية",
    "yemeni universities": "جامعات يمنية",
    "yemeni towns": "بلدات يمنية",
    "yemeni women's sport": "رياضة يمنية نسائية",
    "yemeni parks": "متنزهات يمنية",
    "yemeni musical groups": "فرق موسيقية يمنية",
    "yemeni video games": "ألعاب فيديو يمنية",
    "yemeni magazines": "مجلات يمنية",
    "yemeni plays": "مسرحيات يمنية",
    "yemeni sculptures": "منحوتات يمنية",
    "yemeni businesspeople": "شخصيات أعمال يمنية",
    "yemeni newspapers": "صحف يمنية",
    "yemeni compilation albums": "ألبومات تجميعية يمنية",
    "yemeni lakes": "بحيرات يمنية",
    "yemeni roads": "طرقات يمنية",
    "yemeni television-seasons": "مواسم تلفزيونية يمنية",
    "yemeni mountains": "جبال يمنية",
    "yemeni colonial": "مستعمرات يمنية",
    "yemeni sports competitions": "منافسات رياضية يمنية",
    "yemeni radio stations": "محطات إذاعية يمنية",
    "yemeni operas": "أوبيرات يمنية",
    "yemeni restaurants": "مطاعم يمنية",
    "yemeni temples": "معابد يمنية",
    "yemeni wars": "حروب يمنية",
    "yemeni drink": "مشروبات يمنية",
    "yemeni families": "عائلات يمنية",
    "yemeni titles": "ألقاب يمنية",
    "yemeni discoveries": "اكتشافات يمنية",
    "yemeni border": "حدود يمنية",
    "yemeni names": "أسماء يمنية",
    "yemeni fauna": "حيوانات يمنية",
    "yemeni publications": "منشورات يمنية",
    "yemeni websites": "مواقع ويب يمنية",
    "yemeni cathedrals": "كاتدرائيات يمنية",
    "yemeni tour": "بطولات يمنية",
    "yemeni introductions": "استحداثات يمنية",
    "yemeni short stories": "قصص قصيرة يمنية",
    "yemeni philosophy": "فلسفة يمنية",
    "yemeni television stations": "محطات تلفزيونية يمنية",
    "yemeni rock groups": "فرق روك يمنية",
    "yemeni issues": "قضايا يمنية",
    "yemeni poems": "قصائد يمنية",
    "yemeni societies": "جمعيات يمنية",
    "yemeni brands": "ماركات يمنية",
    "yemeni soundtracks": "موسيقى تصويرية يمنية",
    "yemeni mythology": "أساطير يمنية",
    "yemeni countries": "بلدان يمنية",
    "yemeni referendums": "استفتاءات يمنية",
    "yemeni parishes": "أبرشيات يمنية",
    "yemeni clothing": "ملابس يمنية",
    "yemeni metal musical groups": "فرق موسيقى ميتال يمنية",
    "yemeni peoples": "شعوب يمنية",
    "yemeni forests": "غابات يمنية",
    "yemeni riots": "أعمال شغب يمنية",
    "yemeni monarchy": "ملكية يمنية",
    "yemeni diplomatic missions": "بعثات دبلوماسية يمنية",
    "yemeni provinces": "مقاطعات يمنية",
    "yemeni volcanoes": "براكين يمنية",
    "yemeni popular culture": "ثقافة شعبية يمنية",
    "yemeni resorts": "منتجعات يمنية",
    "yemeni surnames": "ألقاب يمنية",
    "yemeni border crossings": "معابر حدودية يمنية",
    "yemeni rock music groups": "فرق موسيقى الروك يمنية",
    "yemeni executions": "إعدامات يمنية",
    "yemeni war crimes": "جرائم حرب يمنية",
    "yemeni explosions": "انفجارات يمنية",
    "yemeni given names": "أسماء شخصية يمنية",
    "yemeni heritage sites": "موقع تراث عالمي يمنية",
    "yemeni nationalism": "قومية يمنية",
    "yemeni musical instruments": "آلات موسيقية يمنية",
    "yemeni coats of arms": "شعارات نبالة يمنية",
    "yemeni tribes": "قبائل يمنية",
    "yemeni waterfalls": "شلالات يمنية",
    "yemeni military-equipment": "معدات عسكرية يمنية",
    "yemeni trials": "محاكمات يمنية",
    "yemeni terminology": "مصطلحات يمنية",
    "yemeni automotive": "سيارات يمنية",
    "yemeni literary awards": "جوائز أدبية يمنية",
    "yemeni mascots": "تمائم يمنية",
    "yemeni journalism": "صحافة يمنية",
    "yemeni trains": "قطارات يمنية",
    "yemeni television films": "أفلام تلفزيونية يمنية",
    "yemeni film series": "سلاسل أفلام يمنية",
    "yemeni television news": "أخبار تلفزيونية يمنية",
    "yemeni classical music": "موسيقى كلاسيكية يمنية",
    "yemeni football club seasons": "مواسم أندية كرة قدم يمنية",
    "yemeni gangs": "عصابات يمنية",
    "yemeni decorations": "أوسمة يمنية",
    "yemeni rebellions": "تمردات يمنية",
    "yemeni occupations": "مهن يمنية",
    "yemeni awards and decorations": "جوائز وأوسمة يمنية",
    "yemeni non-profit organizations": "منظمات غير ربحية يمنية",
    "yemeni cantons": "كانتونات يمنية",
    "yemeni encyclopedias": "موسوعات يمنية",
    "yemeni ballot measures": "إجراءات اقتراع يمنية",
    "yemeni telenovelas": "تيلينوفيلا يمنية",
    "yemeni inscriptions": "نقوش يمنية",
    "yemeni airstrikes": "ضربات جوية يمنية",
    "yemeni movies": "أفلام يمنية",
    "yemeni folk music": "موسيقى فلكلورية يمنية",
    "yemeni webcomics": "ويب كومكس يمنية",
    "yemeni casualties": "خسائر يمنية",
    "yemeni heavy metal musical groups": "فرق موسيقى هيفي ميتال يمنية",
    "yemeni heraldry": "نبالة يمنية",
    "yemeni television networks": "شبكات تلفزيونية يمنية",
    "yemeni miniseries": "مسلسلات قصيرة يمنية",
    "yemeni folk albums": "ألبومات فلكلورية يمنية",
    "yemeni rectors": "عمدات يمنية",
    "yemeni inventions": "اختراعات يمنية",
    "yemeni pop groups": "فرق بوب يمنية",
    "yemeni learned societies": "جمعيات علمية يمنية",
    "yemeni mixtape albums": "ألبومات ميكستايب يمنية",
    "yemeni masculine given names": "أسماء ذكور يمنية",
    "yemeni archipelagoes": "أرخبيلات يمنية",
    "yemeni webcomic": "ويب كومكس يمنية",
    "yemeni religions": "ديانات يمنية",
    "yemeni budgets": "موازنات يمنية",
    "yemeni classical albums": "ألبومات كلاسيكية يمنية",
    "yemeni musical duos": "فرق موسيقية ثنائية يمنية",
    "yemeni jewellery": "مجوهرات يمنية",
    "yemeni hip hop groups": "فرق هيب هوب يمنية",
    "yemeni pop music groups": "فرق موسيقى بوب يمنية",
    "yemeni civil awards and decorations": "جوائز وأوسمة مدنية يمنية",
    "yemeni revolutions": "ثورات يمنية",
    "yemeni media personalities": "شخصيات إعلامية يمنية",
    "yemeni indie rock groups": "فرق إيندي روك يمنية",
    "yemeni music people": "شخصيات موسيقية يمنية",
    "yemeni folk music groups": "فرق موسيقى تقليدية يمنية",
    "yemeni indie pop groups": "فرق إيندي بوب يمنية",
    "yemeni autobiographies": "ترجمة ذاتية يمنية",
    "yemeni blues musical groups": "فرق موسيقى بلوز يمنية",
    "yemeni memorials and cemeteries": "نصب تذكارية ومقابر يمنية",
    "yemeni memoirs": "مذكرات يمنية",
    "yemeni black metal musical groups": "فرق موسيقى بلاك ميتال يمنية",
    "yemeni folk rock groups": "فرق فولك روك يمنية",
    "yemeni political philosophy": "فلسفة سياسية يمنية",
    "yemeni reggae musical groups": "فرق موسيقى ريغيه يمنية",
    "yemeni swamps": "مستنقعات يمنية",
    "yemeni country music groups": "فرق كانتري يمنية",
    "yemeni world music groups": "فرق موسيقى العالم يمنية",
    "yemeni crimes against humanity": "جرائم ضد الإنسانية يمنية",
    "yemeni radio networks": "شبكات مذياع يمنية",
    "yemeni thrash metal musical groups": "فرق موسيقى ثراش ميتال يمنية",
    "yemeni ska groups": "فرق سكا يمنية",
    "yemeni royal families": "عائلات ملكية يمنية",
    "yemeni comedy albums": "ألبومات كوميدية يمنية",
    "yemeni funk musical groups": "فرق موسيقى فانك يمنية",
    "yemeni ballot propositions": "اقتراحات اقتراع يمنية",
    "yemeni television commercials": "إعلانات تجارية تلفزيونية يمنية",
    "yemeni christian rock groups": "فرق روك مسيحي يمنية",
    "yemeni learned and professional societies": "جمعيات علمية ومهنية يمنية",
    "yemeni professional societies": "جمعيات مهنية يمنية",
    "yemeni eurodance groups": "فرق يورودانس يمنية",
    "yemeni television programs": "برامج تلفزيونية يمنية",
    "yemeni schools and colleges": "مدارس وكليات يمنية",
    "yemeni doom metal musical groups": "فرق موسيقى دوم ميتال يمنية",
    "yemeni gothic metal musical groups": "فرق موسيقى غوثيك ميتال يمنية",
    "yemeni phonologies": "تصريفات صوتية يمنية",
    "yemeni phonology": "نطقيات يمنية",
    "yemeni football club matches": "مباريات أندية كرة قدم يمنية",
    "yemeni contemporary r&b musical groups": "فرق موسيقى آر أند بي معاصر يمنية",
    "yemeni television programmes": "برامج تلفزيونية يمنية",
    "yemeni youth sports competitions": "منافسات رياضية شبابية يمنية",
    "yemeni christian metal musical groups": "فرق موسيقى ميتال مسيحي يمنية",
    "yemeni verbs": "أفعال يمنية",
    "yemeni religious occupations": "مهن دينية يمنية",
    "yemeni electronic dance music groups": "فرق موسيقى الرقص الإلكترونية يمنية",
    "yemeni folklore characters": "شخصيات فلكلورية يمنية",
    "yemeni business culture": "ثقافة مالية يمنية",
    "yemeni military-terminology": "مصطلحات عسكرية يمنية",
    "yemeni online journalism": "صحافة إنترنت يمنية",
    "yemeni underground culture": "ثقافة باطنية يمنية",
    "yemeni comedy music": "موسيقى كوميدية يمنية",
    "yemeni rhythm and blues groups": "فرق ريذم أند بلوز يمنية",
    "yemeni sea temples": "معابد بحرية يمنية",
    "yemeni alternative metal groups": "فرق ميتال بديل يمنية",
    "yemeni contemporary r&b groups": "فرق آر أند بي معاصر يمنية",
    "yemeni entertainment industry businesspeople": "شخصيات أعمال يمنية في صناعة الترفيه",
    "yemeni youth music competitions": "منافسات موسيقية شبابية يمنية",
    "yemeni films": "أفلام يمنية",
    "yemeni events": "أحداث يمنية",
    "yemeni books": "كتب يمنية",
    "yemeni comics": "قصص مصورة يمنية",
    "yemeni paintings": "لوحات يمنية",
    "yemeni political parties": "أحزاب سياسية يمنية",
    "yemeni musicals": "مسرحيات غنائية يمنية",
    "yemeni children's books": "كتب أطفال يمنية",
    "yemeni international schools": "مدارس دولية يمنية",
    "yemeni conferences": "مؤتمرات يمنية",
    "yemeni non-fiction books": "كتب يمنية غير خيالية",
    "yemeni ethnic groups": "مجموعات عرقية يمنية",
    "yemeni fiction novels": "روايات خيالية يمنية",
    "yemeni fiction films": "أفلام خيالية يمنية",
    "yemeni comic": "قصص مصورة يمنية",
    "yemeni organized crime": "جريمة منظمة يمنية",
    "yemeni political organizations": "منظمات سياسية يمنية",
    "yemeni musical films": "أفلام موسيقية يمنية",
    "yemeni texts": "نصوص يمنية",
    "yemeni music awards": "جوائز موسيقى يمنية",
    "yemeni political movements": "حركات سياسية يمنية",
    "yemeni manuscripts": "مخطوطات يمنية",
    "yemeni political organisations": "منظمات سياسية يمنية",
    "yemeni biographical films": "أفلام سير ذاتية يمنية",
    "yemeni islamic organizations": "منظمات إسلامية يمنية",
    "yemeni children's films": "أفلام أطفال يمنية",
    "yemeni comic strips": "شرائط كومكس يمنية",
    "yemeni bibliographies": "ببليوجرافيات يمنية",
    "yemeni music organisations": "منظمات موسيقى يمنية",
    "yemeni historical films": "أفلام تاريخية يمنية",
    "yemeni music organizations": "منظمات موسيقى يمنية",
    "yemeni novellas": "روايات قصيرة يمنية",
    "yemeni documentaries": "وثائقيات يمنية",
    "yemeni experimental films": "أفلام تجريبية يمنية",
    "yemeni historical novels": "روايات تاريخية يمنية",
    "yemeni political films": "أفلام سياسية يمنية",
    "yemeni online encyclopedias": "موسوعات إنترنت يمنية",
    "yemeni children's novels": "روايات أطفال يمنية",
    "yemeni islamic organisations": "منظمات إسلامية يمنية",
    "yemeni illuminated manuscripts": "مخطوطات مذهبة يمنية",
    "yemeni cookbooks": "كتب طبخ يمنية",
    "yemeni children's magazines": "مجلات أطفال يمنية",
    "yemeni history organisations": "منظمات تاريخ يمنية",
    "yemeni history organizations": "منظمات تاريخ يمنية",
    "yemeni legal films": "أفلام قانونية يمنية",
    "yemeni biographical dictionaries": "قواميس سير ذاتية يمنية",
    "yemeni political novels": "روايات سياسية يمنية",
    "yemeni political websites": "مواقع ويب سياسية يمنية",
    "yemeni socialist organizations": "منظمات اشتراكية يمنية",
    "yemeni educational films": "أفلام تعليمية يمنية",
    "yemeni architecture awards": "جوائز عمارة يمنية",
    "yemeni socialist organisations": "منظمات اشتراكية يمنية",
    "yemeni political groups": "مجموعات سياسية يمنية",
    "yemeni non-fiction crime": "جريمة يمنية غير خيالية",
    "yemeni fiction novellas": "روايات قصيرة خيالية يمنية",
    "yemeni architecture organizations": "منظمات عمارة يمنية",
    "yemeni fiction comics": "قصص مصورة خيالية يمنية",
    "yemeni medical organizations": "منظمات طبية يمنية",
    "yemeni biographical novels": "روايات سير ذاتية يمنية",
    "yemeni non-fiction novels": "روايات يمنية غير خيالية",
    "yemeni architecture organisations": "منظمات عمارة يمنية",
    "yemeni fiction comic strips": "شرائط كومكس خيالية يمنية",
    "yemeni biographical comics": "قصص مصورة سير ذاتية يمنية",
    "yemeni children's novellas": "روايات قصيرة أطفال يمنية",
    "yemeni educational comics": "قصص مصورة تعليمية يمنية",
    "yemeni educational webcomics": "ويب كومكس تعليمية يمنية",
    "yemeni historical comics": "قصص مصورة تاريخية يمنية",
    "yemeni historical webcomics": "ويب كومكس تاريخية يمنية",
    "yemeni medical organisations": "منظمات طبية يمنية",
    "yemeni nautical comics": "قصص مصورة بحرية يمنية",
    "yemeni nautical novels": "روايات بحرية يمنية",
    "yemeni non-fiction comics": "قصص مصورة يمنية غير خيالية",
    "yemeni non-fiction comic": "قصص مصورة يمنية غير خيالية",
    "yemeni non-fiction comic strips": "شرائط كومكس يمنية غير خيالية",
    "yemeni non-fiction graphic novels": "روايات مصورة يمنية غير خيالية",
    "yemeni political webcomics": "ويب كومكس سياسية يمنية",
    "yemeni fiction soundtracks": "موسيقى تصويرية خيالية يمنية",
    "yemeni fiction webcomics": "ويب كومكس خيالية يمنية",
    "Members of Christian religious orders": "أعضاء أخويات دينية مسيحية",
    "Christian religious orders by century of establishment": "أخويات دينية مسيحية حسب قرن التأسيس",
    "Christian religious orders established in 11th century": "أخويات دينية مسيحية أسست في القرن 11",
    "Christian religious orders established in 12th century": "أخويات دينية مسيحية أسست في القرن 12",
    "Christian religious orders established in 13th century": "أخويات دينية مسيحية أسست في القرن 13",
    "Christian religious orders established in 14th century": "أخويات دينية مسيحية أسست في القرن 14",
    "Christian religious orders established in 15th century": "أخويات دينية مسيحية أسست في القرن 15",
    "Christian religious orders established in 16th century": "أخويات دينية مسيحية أسست في القرن 16",
    "Christian religious orders established in 17th century": "أخويات دينية مسيحية أسست في القرن 17",
    "Christian religious orders established in 18th century": "أخويات دينية مسيحية أسست في القرن 18",
    "Christian religious orders established in 19th century": "أخويات دينية مسيحية أسست في القرن 19",
    "Christian religious orders established in 20th century": "أخويات دينية مسيحية أسست في القرن 20",
    "Christian religious orders established in 21st century": "أخويات دينية مسيحية أسست في القرن 21",
    "Christian religious orders established in 5th century": "أخويات دينية مسيحية أسست في القرن 5",
    "Christian religious orders established in 6th century": "أخويات دينية مسيحية أسست في القرن 6",
    "Christian political parties by country": "أحزاب سياسية مسيحية حسب البلد",
    "Christian political parties in Australia": "أحزاب سياسية مسيحية في أستراليا",
    "Christian political parties in Canada": "أحزاب سياسية مسيحية في كندا",
    "Christian political parties in Germany": "أحزاب سياسية مسيحية في ألمانيا",
    "Christian political parties in Hungary": "أحزاب سياسية مسيحية في المجر",
    "Christian political parties in Lebanon": "أحزاب سياسية مسيحية في لبنان",
    "Christian political parties in Montenegro": "أحزاب سياسية مسيحية في الجبل الأسود",
    "Christian political parties in New Zealand": "أحزاب سياسية مسيحية في نيوزيلندا",
    "Christian political parties in Papua New Guinea": "أحزاب سياسية مسيحية في بابوا غينيا الجديدة",
    "Christian political parties in Poland": "أحزاب سياسية مسيحية في بولندا",
    "Christian political parties in Quebec": "أحزاب سياسية مسيحية في كيبك",
    "Christian political parties in South Africa": "أحزاب سياسية مسيحية في جنوب إفريقيا",
    "Christian political parties in Ukraine": "أحزاب سياسية مسيحية في أوكرانيا",
    "Christian political parties in United Kingdom": "أحزاب سياسية مسيحية في المملكة المتحدة",
    "Christian political parties in United States": "أحزاب سياسية مسيحية في الولايات المتحدة",
    "Politicians of Christian political parties": "سياسيون من أحزاب سياسية مسيحية",
    "Politicians of Jewish political parties": "سياسيون من أحزاب سياسية يهودية",
    "Christian texts by century": "نصوص مسيحية حسب القرن",
    "Christian texts by genre": "نصوص مسيحية حسب النوع الفني",
    "Christian texts by medium": "نصوص مسيحية حسب الوسط",
    "Christian texts by millennium": "نصوص مسيحية حسب الألفية",
    "Christian texts by period": "نصوص مسيحية حسب الحقبة",
    "christian texts": "نصوص مسيحية",
    "Jewish texts by century": "نصوص يهودية حسب القرن",
    "jewish texts": "نصوص يهودية",
    "jewish rock groups": "فرق روك يهودية",
    "christian events": "أحداث مسيحية",
    "christian political organizations": "منظمات سياسية مسيحية",
    "christian rock groups": "فرق روك مسيحية",
    "jewish history organizations": "منظمات تاريخ يهودية",
    "jewish political organizations": "منظمات سياسية يهودية",
    "jewish religious organizations": "منظمات دينية يهودية",
    "Kurdish Islamic organisations": "منظمات إسلامية كردية",
    "kurdish islamic organizations": "منظمات إسلامية كردية",
    "jewish sports organizations": "منظمات ألعاب رياضية يهودية",
    "christian sports organizations": "منظمات ألعاب رياضية مسيحية",
    "romanian motorsport people": "أعلام رياضة المحركات الرومانية",
    "american culture": "ثقافة أمريكية",
    "antigua and barbuda sport": "رياضة أنتيغوية وبربودية",
    "armenian television": "التلفزة الأرمينية",
    "asian restaurants": "مطاعم آسيوية",
    "asian-american people": "أمريكيون آسيويون",
    "austrian television series": "مسلسلات تلفزيونية نمساوية",
    "bangladeshi films": "أفلام بنغلاديشية",
    "bangladeshi politics": "السياسة البنغلاديشية",
    "belgian companies": "شركات بلجيكية",
    "bhutanese sport": "رياضة بوتانية",
    "brazilian football club seasons": "مواسم أندية كرة قدم برازيلية",
    "british women's sport": "رياضة بريطانية نسائية",
    "burmese names": "أسماء بورمية",
    "byzantine titles": "ألقاب بيزنطية",
    "canadian films": "أفلام كندية",
    "canadian music": "موسيقى كندية",
    "central american football": "كرة القدم الأمريكية الأوسطية",
    "chinese music": "موسيقى صينية",
    "christian educational organizations": "منظمات تعليمية مسيحية",
    "christian organizations": "منظمات مسيحية",
    "croatian music": "موسيقى كرواتية",
    "czech women's sport": "رياضة تشيكية نسائية",
    "danish books": "كتب دنماركية",
    "east german sport": "رياضة ألمانية شرقية",
    "emirati sport": "رياضة إماراتية",
    "english tennis": "كرة المضرب الإنجليزية",
    "eritrean war crimes": "جرائم حرب إريترية",
    "estonian music people": "شخصيات موسيقية إستونية",
    "ethiopian war crimes": "جرائم حرب إثيوبية",
    "european restaurants": "مطاعم أوروبية",
    "european-argentine culture": "ثقافة أرجنتينية أوروبية",
    "filipino-american culture": "ثقافة أمريكية فلبينية",
    "french restaurants": "مطاعم فرنسية",
    "french wars": "حروب فرنسية",
    "gothic architecture": "عمارة قوطية",
    "greek television series": "مسلسلات تلفزيونية يونانية",
    "hong kong sport": "رياضة هونغ كونغية",
    "hungarian sport": "رياضة مجرية",
    "hungarian websites": "مواقع ويب مجرية",
    "indian companies": "شركات هندية",
    "irish comedy": "كوميديا أيرلندية",
    "irish universities": "جامعات أيرلندية",
    "italian restaurants": "مطاعم إيطالية",
    "ivorian companies": "شركات إيفوارية",
    "japanese restaurants": "مطاعم يابانية",
    "japanese war crimes": "جرائم حرب يابانية",
    "jewish educational organizations": "منظمات تعليمية يهودية",
    "jewish music": "موسيقى يهودية",
    "jewish organizations": "منظمات يهودية",
    "kyrgyzstani sport": "رياضة قيرغيزستانية",
    "lebanese television series": "مسلسلات تلفزيونية لبنانية",
    "lithuanian films": "أفلام ليتوانية",
    "malawian websites": "مواقع ويب ملاوية",
    "mexican restaurants": "مطاعم مكسيكية",
    "mexican-american culture": "ثقافة أمريكية مكسيكية",
    "moroccan television series": "مسلسلات تلفزيونية مغربية",
    "nepali television": "التلفزة النيبالية",
    "nigerian football": "كرة القدم النيجيرية",
    "north american culture": "ثقافة أمريكية شمالية",
    "northern ireland sport": "رياضة أيرلندية شمالية",
    "ottoman classical music": "موسيقى كلاسيكية عثمانية",
    "pakistani football": "كرة القدم الباكستانية",
    "philippine football": "كرة القدم الفلبينية",
    "philippine presidential election": "انتخابات الرئاسة الفلبينية",
    "philippine television commercials": "إعلانات تجارية تلفزيونية فلبينية",
    "qatari football ": "كرة القدم القطرية",
    "romanian clothing": "ملابس رومانية",
    "romanian motorsport": "رياضة المحركات الرومانية",
    "romanian restaurants": "مطاعم رومانية",
    "romanian sport": "رياضة رومانية",
    "russian politics": "السياسة الروسية",
    "scottish islands": "جزر إسكتلندية",
    "scottish sports": "ألعاب رياضية إسكتلندية",
    "slovenian sport": "رياضة سلوفينية",
    "soviet navy": "البحرية السوفيتية",
    "soviet war crimes": "جرائم حرب سوفيتية",
    "spanish films": "أفلام إسبانية",
    "surinamese sport": "رياضة سورينامية",
    "swedish air force": "القوات الجوية السويدية",
    "swiss businesspeople": "شخصيات أعمال سويسرية",
    "syrian websites": "مواقع ويب سورية",
    "thai television": "التلفزة التايلندية",
    "trinidad and tobago football": "كرة القدم الترنيدادية",
    "vietnamese sport": "رياضة فيتنامية",
    "yemeni civil war": "الحرب الأهلية اليمنية",
    "yoruba names": "أسماء يوروبية",
    "asian games bronze medalists": "فائزون بميداليات برونزية في الألعاب الآسيوية",
    "azerbaijani encyclopedias": "موسوعات أذربيجانية",
    "azerbaijani football club seasons": "مواسم أندية كرة قدم أذربيجانية",
    "bahamian awards": "جوائز بهامية",
    "bangladesh cinema": "السينما البنغلاديشية",
    "bangladeshi awards": "جوائز بنغلاديشية",
    "bangladeshi companies": "شركات بنغلاديشية",
    "bangladeshi folk music": "موسيقى فلكلورية بنغلاديشية",
    "belarusian sport": "رياضة بيلاروسية",
    "belgian detention": "المعتقلات البلجيكية",
    "belgian novels": "روايات بلجيكية",
    "beninese sport": "رياضة بنينية",
    "bolivian television series": "مسلسلات تلفزيونية بوليفية",
    "brazilian television series": "مسلسلات تلفزيونية برازيلية",
    "british medical association": "الجمعية الطبية البريطانية",
    "british music": "موسيقى بريطانية",
    "british plays": "مسرحيات بريطانية",
    "british restaurants": "مطاعم بريطانية",
    "burmese sport": "رياضة بورمية",
    "cambodian sport": "رياضة كمبودية",
    "cameroonian football": "كرة القدم الكاميرونية",
    "canadian journalism": "صحافة كندية",
    "canadian magazines": "مجلات كندية",
    "cape verdean awards": "جوائز رأس أخضرية",
    "central american cinema": "السينما الأمريكية الأوسطية",
    "chilean football": "كرة القدم التشيلية",
    "chilean navy": "البحرية التشيلية",
    "chilean sport": "رياضة تشيلية",
    "chinese businesspeople": "شخصيات أعمال صينية",
    "chinese sport": "رياضة صينية",
    "christian radio stations": "محطات إذاعية مسيحية",
    "comorian football": "كرة القدم القمرية",
    "congolese movement": "الحركة الكونغوية",
    "croatian war crimes": "جرائم حرب كرواتية",
    "cypriot football": "كرة القدم القبرصية",
    "czech air force": "القوات الجوية التشيكية",
    "czech politics": "السياسة التشيكية",
    "czechoslovak television": "التلفزة التشيكوسلوفاكية",
    "danish football": "كرة القدم الدنماركية",
    "danish islands": "جزر دنماركية",
    "danish sport": "رياضة دنماركية",
    "danish television": "التلفزة الدنماركية",
    "dominican culture": "ثقافة دومينيكية",
    "dutch novels": "روايات هولندية",
    "english women's sport": "رياضة إنجليزية نسائية",
    "equatoguinean sport": "رياضة غينية استوائية",
    "estonian sport": "رياضة إستونية",
    "ethiopian sport": "رياضة إثيوبية",
    "european border": "حدود أوروبية",
    "european games silver medalists": "فائزون بميداليات فضية في الألعاب الأوروبية",
    "european music": "موسيقى أوروبية",
    "fijian football": "كرة القدم الفيجية",
    "finnish awards and decorations": "جوائز وأوسمة فنلندية",
    "finnish navy": "البحرية الفنلندية",
    "finnish novels": "روايات فنلندية",
    "finnish sport": "رياضة فنلندية",
    "finnish television series": "مسلسلات تلفزيونية فنلندية",
    "french cinema": "السينما الفرنسية",
    "french legal films": "أفلام قانونية فرنسية",
    "french mythology": "أساطير فرنسية",
    "french navy": "البحرية الفرنسية",
    "french sport": "رياضة فرنسية",
    "french war crimes": "جرائم حرب فرنسية",
    "german music": "موسيقى ألمانية",
    "german women's sport": "رياضة ألمانية نسائية",
    "greek companies": "شركات يونانية",
    "greek novels": "روايات يونانية",
    "greek poems": "قصائد يونانية",
    "greek women's sport": "رياضة يونانية نسائية",
    "greenlandic sport": "رياضة جرينلاندية",
    "guamanian football": "كرة القدم الغوامية",
    "guatemalan musical instruments": "آلات موسيقية غواتيمالية",
    "gujarati films": "أفلام غجراتية",
    "hungarian women's sport": "رياضة مجرية نسائية",
    "indian politics": "السياسة الهندية",
    "indonesian websites": "مواقع ويب إندونيسية",
    "iranian television series": "مسلسلات تلفزيونية إيرانية",
    "irish films": "أفلام أيرلندية",
    "irish general election": "الانتخابات العامة الأيرلندية",
    "israeli brands": "ماركات إسرائيلية",
    "israeli sport": "رياضة إسرائيلية",
    "israeli women's sport": "رياضة إسرائيلية نسائية",
    "jamaican brands": "ماركات جامايكية",
    "japanese companies": "شركات يابانية",
    "japanese music": "موسيقى يابانية",
    "japanese politics": "السياسة اليابانية",
    "japanese sport": "رياضة يابانية",
    "jewish american television series": "مسلسلات تلفزيونية أمريكية يهودية",
    "jewish american tennis": "كرة مضرب أمريكية يهودية",
    "jordanian football": "كرة القدم الأردنية",
    "kenyan novels": "روايات كينية",
    "kenyan television series": "مسلسلات تلفزيونية كينية",
    "korean businesspeople": "شخصيات أعمال كورية",
    "kyrgyzstani football": "كرة القدم القيرغيزستانية",
    "luxembourgian sport": "رياضة لوكسمبورغية",
    "luxembourgish inventions": "اختراعات لوكسمبورغية",
    "malaysian football": "كرة القدم الماليزية",
    "malaysian sport": "رياضة ماليزية",
    "mexican businesspeople": "شخصيات أعمال مكسيكية",
    "mexican novels": "روايات مكسيكية",
    "mexican politics": "السياسة المكسيكية",
    "mexican television series": "مسلسلات تلفزيونية مكسيكية",
    "monégasque sport": "رياضة موناكية",
    "native american films": "أفلام أمريكية أصلية",
    "nicaraguan football": "كرة القدم النيكاراغوية",
    "nigerian sport": "رياضة نيجيرية",
    "north american sport": "رياضة أمريكية شمالية",
    "norwegian military academy": "الأكاديمية العسكرية النرويجية",
    "norwegian music": "موسيقى نرويجية",
    "pakistani politics": "السياسة الباكستانية",
    "pakistani sport": "رياضة باكستانية",
    "pakistani television": "التلفزة الباكستانية",
    "palestinian organizations": "منظمات فلسطينية",
    "paraguayan films": "أفلام بارغوايانية",
    "peruvian sport": "رياضة بيروية",
    "peruvian television series": "مسلسلات تلفزيونية بيروية",
    "peruvian television": "التلفزة البيروية",
    "philippine revolution": "الثورة الفلبينية",
    "polish companies": "شركات بولندية",
    "polish football": "كرة القدم البولندية",
    "polish music": "موسيقى بولندية",
    "polish sport": "رياضة بولندية",
    "polish television": "التلفزة البولندية",
    "portuguese companies": "شركات برتغالية",
    "portuguese sport": "رياضة برتغالية",
    "puerto rican brands": "ماركات بورتوريكية",
    "qatari musical instruments": "آلات موسيقية قطرية",
    "russian journalism": "صحافة روسية",
    "russian revolution": "الثورة الروسية",
    "russian songs": "أغاني روسية",
    "samoan islands": "جزر ساموية",
    "scottish businesspeople": "شخصيات أعمال إسكتلندية",
    "scottish television": "التلفزة الإسكتلندية",
    "sierra leonean sport": "رياضة سيراليونية",
    "singaporean media personalities": "شخصيات إعلامية سنغافورية",
    "singaporean plays": "مسرحيات سنغافورية",
    "slovak music": "موسيقى سلوفاكية",
    "slovenian novels": "روايات سلوفينية",
    "south american sport": "رياضة أمريكية جنوبية",
    "south korean sport": "رياضة كورية جنوبية",
    "soviet football": "كرة القدم السوفيتية",
    "spanish companies": "شركات إسبانية",
    "sri lankan novels": "روايات سريلانكية",
    "sri lankan television": "التلفزة السريلانكية",
    "swedish inventions": "اختراعات سويدية",
    "swedish novels": "روايات سويدية",
    "swedish plays": "مسرحيات سويدية",
    "swedish war": "الحرب السويدية",
    "swiss books": "كتب سويسرية",
    "swiss detention": "المعتقلات السويسرية",
    "swiss websites": "مواقع ويب سويسرية",
    "syrian navy": "البحرية السورية",
    "syrian sport": "رياضة سورية",
    "tanzanian brands": "ماركات تنزانية",
    "tanzanian sport": "رياضة تنزانية",
    "thai families": "عائلات تايلندية",
    "thai films": "أفلام تايلندية",
    "turkish awards": "جوائز تركية",
    "tuvaluan football": "كرة القدم التوفالية",
    "ugandan television": "التلفزة الأوغندية",
    "ukrainian films": "أفلام أوكرانية",
    "ukrainian sport": "رياضة أوكرانية",
    "ukrainian television": "التلفزة الأوكرانية",
    "ukrainian works": "أعمال أوكرانية",
    "uruguayan war": "الحرب الأوروغويانية",
    "uzbekistani films": "أفلام أوزبكستانية",
    "venezuelan sport": "رياضة فنزويلية",
    "venezuelan television": "التلفزة الفنزويلية",
    "vietnamese companies": "شركات فيتنامية",
    "vietnamese women's sport": "رياضة فيتنامية نسائية",
    "welsh sport": "رياضة ويلزية",
    "yugoslav sport": "رياضة يوغسلافية",
    "zimbabwean companies": "شركات زيمبابوية",
    "zimbabwean general election": "الانتخابات العامة الزيمبابوية",
}

data1 = {
    "Lists of office-holders in 2014": "قوائم أصحاب المناصب في 2014",
    "Lists of office-holders in Armenia": "قوائم أصحاب المناصب في أرمينيا",
    "Lists of office-holders in Syria": "قوائم أصحاب المناصب في سوريا",
    "Christian Science in England": "علم مسيحي في إنجلترا",
    "Christian fiction": "خيال مسيحي",
    "Christian Science in California": "علم مسيحي في كاليفورنيا",
    "Christian Science in Canada": "علم مسيحي في كندا",
    "Christian Science in Colorado": "علم مسيحي في كولورادو",
    "Christian Science in Connecticut": "علم مسيحي في كونيتيكت",
    "Christian Science in Florida": "علم مسيحي في فلوريدا",
    "Christian Science in Germany": "علم مسيحي في ألمانيا",
    "Christian Science in Illinois": "علم مسيحي في إلينوي",
    "Christian Science in Massachusetts": "علم مسيحي في ماساتشوستس",
    "Christian Science in Missouri": "علم مسيحي في ميزوري",
    "Christian Science in New York (state)": "علم مسيحي في ولاية نيويورك",
    "Christian Science in New York City": "علم مسيحي في مدينة نيويورك",
    "Christian Science in United Kingdom": "علم مسيحي في المملكة المتحدة",
    "Christian Science in United States by state": "علم مسيحي في الولايات المتحدة حسب الولاية",
    "Christian Science in United States": "علم مسيحي في الولايات المتحدة",
    "Christian Science in Washington (state)": "علم مسيحي في ولاية واشنطن",
    "Christian Science in Wisconsin": "علم مسيحي في ويسكونسن",
    "Christian Science": "علم مسيحي",
    "Critics of Christian Science": "نقاد من علم مسيحي",
    "1888 in American sports": "ألعاب رياضية أمريكية في 1888",
    "1919 in American motorsport": "رياضة المحركات الأمريكية في 1919",
    "1919 in American tennis": "كرة المضرب الأمريكية في 1919",
    "1930 in Australian tennis": "كرة المضرب الأسترالية في 1930",
    "1931 in American motorsport": "رياضة المحركات الأمريكية في 1931",
    "1937 in Belgian motorsport": "رياضة المحركات البلجيكية في 1937",
    "1970s in Australian tennis": "كرة المضرب الأسترالية في عقد 1970",
    "1971 in American tennis": "كرة المضرب الأمريكية في 1971",
    "1974 in West German motorsport": "رياضة المحركات الألمانية الغربية في 1974",
    "1984 in American motorsport": "رياضة المحركات الأمريكية في 1984",
    "1987 in American sports by state": "ألعاب رياضية أمريكية في 1987 حسب الولاية",
    "1990s in Colombian tennis": "كرة المضرب الكولومبية في عقد 1990",
    "1991 in Australian tennis": "كرة المضرب الأسترالية في 1991",
    "1997 in British motorsport": "رياضة المحركات البريطانية في 1997",
    "1998 in Indian tennis": "كرة المضرب الهندية في 1998",
    "2000 in Canadian sports by province or territory": "ألعاب رياضية كندية في 2000 حسب المقاطعة أو الإقليم",
    "2004 in Chilean tennis": "كرة المضرب التشيلية في 2004",
    "2004 in French motorsport": "رياضة المحركات الفرنسية في 2004",
    "2005 in Australian tennis": "كرة المضرب الأسترالية في 2005",
    "2010s in Taiwanese tennis": "كرة المضرب التايوانية في عقد 2010",
    "Ancient Egyptian Jews": "مصريون قدماء يهود",
    "Canarian Jews": "كناريون يهود",
    "Ancient Christian saints": "قديسون قدماء",
    "works by gotthold ephraim lessing": "أعمال إفرايم ليسينغ",
    "works by leo tolstoy": "أعمال ليو تولستوي",
    "works by osamu tezuka": "أعمال أوسامو تزوكا",
    "2012 in Luxembourgian tennis": "كرة المضرب اللوكسمبورغية في 2012",
    "2013 in Hungarian motorsport": "رياضة المحركات المجرية في 2013",
    "2020 in French tennis": "كرة المضرب الفرنسية في 2020",
    "2020s in Thai motorsport": "رياضة المحركات التايلندية في عقد 2020",
    "2023 in Malaysian motorsport": "رياضة المحركات الماليزية في 2023",
    "Women's soccer players in United States by competition": "لاعبات كرة قدم في الولايات المتحدة حسب المنافسة",
    "1999–2000 in European rugby union leagues": "دوريات اتحاد الرجبي الأوروبي في 1999–2000",
    "2016–17 in European women's rugby union": "اتحاد رجبي أوروبية للسيدات في 2016–17",
    "Hong Kong motorsport people": "أعلام رياضة المحركات الهونغ الكونغية",
    "American football culture": "ثقافة كرة قدم أمريكية",
    "2012–13 in Spanish rugby union leagues": "دوريات اتحاد الرجبي الإسباني في 2012–13",
    "american football films": "أفلام كرة قدم أمريكية",
    "Men's footballers in Azerbaijan by competition": "لاعبو كرة قدم في أذربيجان حسب المنافسة",
    "Men's footballers in Guinea-Bissau by club": "لاعبو كرة قدم في غينيا بيساو حسب النادي",
    "Men's footballers in Portugal by competition": "لاعبو كرة قدم في البرتغال حسب المنافسة",
    "Men's footballers in Slovenia by club": "لاعبو كرة قدم في سلوفينيا حسب النادي",
    "Men's footballers in Solomon Islands by club": "لاعبو كرة قدم في جزر سليمان حسب النادي",
    "Men's footballers in Tajikistan by club": "لاعبو كرة قدم في طاجيكستان حسب النادي",
    "Founders of motor vehicle manufacturers by nationality": "مؤسسي مصانع السيارات حسب الجنسية",
    "Founders of motor vehicle manufacturers": "مؤسسي مصانع السيارات",
    "american football governing bodies": "هيئات تنظيم كرة قدم أمريكية",
    "1828 New Jersey elections": "انتخابات نيوجيرسي في 1828",
    "cuban football logos": "شعارات كرة القدم الكوبية",
    "thai league cup": "كأس الدوري التايلندي",
    "lao premier league seasons": "مواسم الدوري اللاوسي الممتاز",
    "american indoor soccer league seasons": "مواسم الدوري الأمريكي لكرة القدم داخل الصالات",
    "male actors from west midlands (county)": "ممثلون ذكور من مقاطعة ميدلاند الغربية",
    "Canadian football players in Edmonton": "لاعبو كرة قدم كندية في إدمونتون",
    "christian saints": "قديسون",
    "electro musicians": "موسيقيو موسيقى كهربائية",
    "film editors": "محررو أفلام",
    "gardeners": "مزارعو حدائق",
    "music journalists": "صحفيون موسيقيون",
    "olympic beach volleyball players": "لاعبو كرة طائرة شاطئية أولمبيون",
    "olympic divers": "غواصون أولمبيون",
    "olympic handball players": "لاعبو كرة يد أولمبيون",
    "olympic judoka": "لاعبو جودو أولمبيون",
    "olympic nordic combined skiers": "متزحلقو تزلج نوردي مزدوج أولمبيون",
    "polo players": "لاعبو بولو",
    "traditional pop music singers": "مغنو موسيقى بوب تقليدية",
    "voice actresses": "ممثلات أداء صوتي",
    "male models": "عارضو أزياء ذكور",
    "male sport shooters": "لاعبو رماية ذكور",
    "assassinated politicians": "سياسيون مغتالون",
    "18th-century Dutch explorers": "مستكشفون هولنديون في القرن 18",
    "1650s crimes": "جرائم عقد 1650",
    "20th century women musicians": "موسيقيات في القرن 20",
    "20th century canadian violinists": "عازفو كمان كنديون في القرن 20",
    "20th century russian dramatists": "دراميون روس في القرن 20",
    "20th century polish dramatists": "دراميون بولنديون في القرن 20",
    "20th century chinese dramatists": "دراميون صينيون في القرن 20",
    "20th century dramatists": "دراميون في القرن 20",
    "20th century english dramatists": "دراميون إنجليز في القرن 20",
    "20th century israeli dramatists": "دراميون إسرائيليون في القرن 20",
    "italian defectors to soviet union": "إيطاليون منشقون إلى الاتحاد السوفيتي",
    "zambian emigrants to sweden": "زامبيون مهاجرون إلى السويد",
    "sri lankan emigrants to india": "سريلانكيون مهاجرون إلى الهند",
    "taiwanese emigrants to argentina": "تايوانيون مهاجرون إلى الأرجنتين",
    "polish emigrants to brazil": "بولنديون مهاجرون إلى البرازيل",
    "italian emigrants to finland": "إيطاليون مهاجرون إلى فنلندا",
    "icelandic emigrants to new zealand": "آيسلنديون مهاجرون إلى نيوزيلندا",
    "german emigrants to scotland": "ألمان مهاجرون إلى إسكتلندا",
    "croatian emigrants to netherlands": "كروات مهاجرون إلى هولندا",
    "cypriot emigrants to israel": "قبرصيون مهاجرون إلى إسرائيل",
    "chinese emigrants to thailand": "صينيون مهاجرون إلى تايلاند",
    "british emigrants to switzerland": "بريطانيون مهاجرون إلى سويسرا",
    "british emigrants to zimbabwe": "بريطانيون مهاجرون إلى زيمبابوي",
    "American child classical musicians": "موسيقيون كلاسيكيون أمريكيون أطفال",
    "Canadian child singers": "مغنون كنديون أطفال",
    "Native American people in American Revolution": "أمريكيون أصليون في الثورة الأمريكية",
    "Yugoslav disabled sports-people": "رياضيون يوغسلافيون معاقون",
    "American women in politics by descent": "أمريكيات في السياسة حسب الأصل",
    "Native American people from Minnesota": "أمريكيون أصليون من منيسوتا",
    "Native American people from North Dakota": "أمريكيون أصليون من داكوتا الشمالية",
    "Native American people from South Dakota": "أمريكيون أصليون من داكوتا الجنوبية",
    "Native American people from Washington (state)": "أمريكيون أصليون من ولاية واشنطن",
    "Somalian disabled sports-people": "رياضيون صوماليون معاقون",
    "Ancient Jews by occupation": "يهود قدماء حسب المهنة",
    "Ancient Jews": "يهود قدماء",
    "Fictional American Jews in comics": "أمريكيون يهود خياليون في قصص مصورة",
    "Fictional American Jews": "أمريكيون يهود خياليون",
    "Fictional Argentine Jews": "أرجنتينيون يهود خياليون",
    "Fictional British Jews": "بريطانيون يهود خياليون",
    "Fictional Canadian Jews": "كنديون يهود خياليون",
    "Fictional English Jews": "إنجليز يهود خياليون",
    "Fictional German Jews": "ألمان يهود خياليون",
    "Fictional Israeli Jews": "إسرائيليون يهود خياليون",
    "Fictional Italian Jews": "إيطاليون يهود خياليون",
    "Fictional Polish Jews": "بولنديون يهود خياليون",
    "Fictional Russian Jews": "روس يهود خياليون",
    "Fictional Serbian Jews": "صرب يهود خياليون",
    "Political office-holders in Northern Ireland by county": "أصحاب مناصب سياسية في أيرلندا الشمالية حسب المقاطعة",
    "Lists of political office-holders in Northern Ireland": "قوائم أصحاب مناصب سياسية في أيرلندا الشمالية",
    "Lists of political office-holders in South Africa": "قوائم أصحاب مناصب سياسية في جنوب إفريقيا",
    "lists of political office-holders": "قوائم أصحاب مناصب سياسية",
    "1991 in Canadian sports by province or territory": "ألعاب رياضية كندية في 1991 حسب المقاطعة أو الإقليم",
    "Scottish sports trophies and awards": "جوائز وإنجازات ألعاب رياضية إسكتلندية",
    "2026 in American sports by month": "ألعاب رياضية أمريكية في 2026 حسب الشهر",
    "2026 in American sports by state": "ألعاب رياضية أمريكية في 2026 حسب الولاية",
    "2026 in American sports": "ألعاب رياضية أمريكية في 2026",
    "2026 in Canadian sports by month": "ألعاب رياضية كندية في 2026 حسب الشهر",
    "2026 in Canadian sports by province or territory": "ألعاب رياضية كندية في 2026 حسب المقاطعة أو الإقليم",
    "2026 in Canadian sports": "ألعاب رياضية كندية في 2026",
    "2026 in Mexican sports by month": "ألعاب رياضية مكسيكية في 2026 حسب الشهر",
    "2026 in Mexican sports": "ألعاب رياضية مكسيكية في 2026",
    "2025 in Qatari motorsport": "رياضة المحركات القطرية في 2025",
    "2026 in American motorsport": "رياضة المحركات الأمريكية في 2026",
    "2026 in Australian motorsport": "رياضة المحركات الأسترالية في 2026",
    "2026 in Emirati motorsport": "رياضة المحركات الإماراتية في 2026",
    "2026 in French motorsport": "رياضة المحركات الفرنسية في 2026",
    "2026 in German motorsport": "رياضة المحركات الألمانية في 2026",
    "2026 in Japanese motorsport": "رياضة المحركات اليابانية في 2026",
    # "American expatriate men's soccer players in Canada": "",
    "West German men sprinters": "عداؤون سريعون ألمانيون غربيون",
    "Emirati men's footballers": "لاعبو كرة قدم إماراتيون",
    "2015 American television": "التلفزة الأمريكية 2015",
    # "yemeni presidential elections": "انتخابات اليمن الرئاسية",
    "ambassadors of federated states of micronesia in yemen by year": "سفراء ولايات ميكرونيسيا المتحدة في اليمن حسب السنة",
    "Adaptations of works by Greek writers": "أعمال مقتبسة عن أعمال كتاب يونانيون",
    "Adaptations of works by Irish writers": "أعمال مقتبسة عن أعمال كتاب أيرلنديون",
    "Adaptations of works by Italian writers": "أعمال مقتبسة عن أعمال كتاب إيطاليون",
    "sieges of french invasion of egypt and syria": "حصارات الغزو الفرنسي لمصر وسوريا",
    "1330 in men's international football": "كرة قدم دولية للرجال في 1330",
    "2017 American television series": "مسلسلات تلفزيونية أمريكية في 2017",
    "Cross-country skiers at 1992 Winter Paralympics": "متزحلقون ريفيون في الألعاب البارالمبية الشتوية 1992",
    "2017 American television episodes": "حلقات تلفزيونية أمريكية في 2017",
    "2017 American television seasons": "مواسم تلفزيونية أمريكية في 2017",
    "Roller skaters at 2003 Pan American Games": "متزلجون بالعجلات في دورة الألعاب الأمريكية 2003",
    "Ski jumpers at 2007 Winter Universiade": "متزلجو قفز في الألعاب الجامعية الشتوية 2007",
    "Figure skaters at 2002 Winter Olympics": "متزلجون فنيون في الألعاب الأولمبية الشتوية 2002",
    "Figure skaters at 2003 Asian Winter Games": "متزلجون فنيون في الألعاب الآسيوية الشتوية 2003",
    "Figure skaters at 2007 Winter Universiade": "متزلجون فنيون في الألعاب الجامعية الشتوية 2007",
    "Nations at 2010 Summer Youth Olympics": "بلدان في الألعاب الأولمبية الشبابية الصيفية 2010",
    "military personnel of republic-of china": "أفراد عسكريون من جمهورية الصين",
    "children of prime ministers of ukraine": "أبناء رؤساء وزراء أوكرانيا",
    # "roman catholic bishops of fulda": "",
    "men of poseidon": "رجال من بوسيدون",
    "Olympic shooters of Egypt": "رماة أولمبيون من مصر",
    "Olympic short track speed skaters of Japan": "متزلجون على مسار قصير أولمبيون من اليابان",
    "Olympic figure skaters of Argentina": "متزلجون فنيون أولمبيون من الأرجنتين",
    "Olympic figure skaters of Armenia": "متزلجون فنيون أولمبيون من أرمينيا",
    "Olympic figure skaters of Australia": "متزلجون فنيون أولمبيون من أستراليا",
    # "communists of bosnia and herzegovina politicians": "أحداث أكتوبر 1550 الرياضية في أوقيانوسيا",
}

data_test2 = {
    "Schools for deaf in New York (state)": "مدارس للصم في ولاية نيويورك",
    "Cabinets involving Liberal Party (Norway)": "",
    "Television plays directed by William Sterling (director)": "",
    "Television plays filmed in Brisbane": "مسرحيات تلفزيونية صورت في بريزبان",
    "Television personalities from Yorkshire": "شخصيات تلفزيون من يوركشاير",
    "Cabinets involving Progress Party (Norway)": "مجالس وزراء تشمل حزب التقدم (النرويج)",
    "100 metres at African Championships in Athletics": "",
    "100 metres at IAAF World Youth Championships in Athletics": "",
    "100 metres at World Para Athletics Championships": "",
    "Documentary films about 2011 Tōhoku earthquake and tsunami": "",
    "People accused of lèse majesté in Thailand": "",
    "People accused of lèse majesté in Thailand since 2020": "",
    "People associated with former colleges of University of London": "",
    "People associated with Nazarene universities and colleges": "",
}


data_list_bad = {
    # "20th century roman catholic archbishops in colombia": "رؤساء أساقفة رومان كاثوليك في كولومبيا القرن 20",
    # "20th century disasters in afghanistan": "كوارث القرن 20 في أفغانستان",
    # "20th century churches in ethiopia": "كنائس في إثيوبيا القرن 20",
    # "20th century churches in nigeria": "كنائس في نيجيريا القرن 20",
    "Paralympic competitors for Cape Verde": "منافسون بارالمبيون من الرأس الأخضر",
    "20th century american people by occupation": "أمريكيون في القرن 20 حسب المهنة",
    "20th century people from al-andalus": "أشخاص من الأندلس في القرن 20",
    "1550s disestablishments in yugoslavia": "انحلالات عقد 1550 في يوغسلافيا",
    "20th century disestablishments in united kingdom": "انحلالات القرن 20 في المملكة المتحدة",
    "1550s establishments in wisconsin": "تأسيسات عقد 1550 في ويسكونسن",
    "20th century disestablishments in sri lanka": "انحلالات القرن 20 في سريلانكا",
    "3rd millennium disestablishments in england": "انحلالات الألفية 3 في إنجلترا",
    "1550s crimes in pakistan": "جرائم عقد 1550 في باكستان",
    "2nd millennium establishments in rhode island": "تأسيسات الألفية 2 في رود آيلاند",
    "1550s establishments in chile": "تأسيسات عقد 1550 في تشيلي",
    "1550s disestablishments in southeast asia": "انحلالات عقد 1550 في جنوب شرق آسيا",
    "1550s establishments in jamaica": "تأسيسات عقد 1550 في جامايكا",
    "1550s disestablishments in mississippi": "انحلالات عقد 1550 في مسيسيبي",
    "1550s establishments in maine": "تأسيسات عقد 1550 في مين",
    "1550s establishments in sweden": "تأسيسات عقد 1550 في السويد",
    "20th century disestablishments in newfoundland and labrador": "انحلالات القرن 20 في نيوفاوندلاند واللابرادور",
    "20th century disestablishments in danish colonial empire": "انحلالات القرن 20 في الإمبراطورية الاستعمارية الدنماركية",
    "20th century establishments in french guiana": "تأسيسات القرن 20 في غويانا الفرنسية",
    "20th century establishments in ireland": "تأسيسات القرن 20 في أيرلندا",
    "20th century monarchs by country": "ملكيون في القرن 20 حسب البلد",
    "july 1550 crimes by continent": "جرائم يوليو 1550 حسب القارة",
}


to_test = [
    ("test_2_test_1", data1),
    ("test_2_fast_data", fast_data),
    ("test_2_test_2", data_test2),
    ("test_2_new_bug_check", data_list_bad),
]


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_2_fast_data(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_test2.items(), ids=data_test2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_list_bad.items(), ids=data_list_bad.keys())
@pytest.mark.fast
def test_2_new_bug_check(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Utility helpers shared across the :mod:`translations.sports` package.

The original sports modules relied on ad-hoc loops to generate large
collections of translated sports labels.  The helpers in this module
centralise the common logic so that the individual modules remain readable
and well typed.
"""

from __future__ import annotations

from collections.abc import Iterable, Mapping, MutableMapping
from string import Formatter
from typing import Any

from ...helps import logger

# The list of age categories that appear throughout the sports templates.
# It is referenced from multiple modules, therefore it lives in a single
# shared location to keep definitions consistent.
YEARS: tuple[int, ...] = (13, 14, 15, 16, 17, 18, 19, 20, 21, 23, 24)


def _count_positional_fields(template: str) -> int:
    """Return the number of anonymous positional fields in ``template``."""

    formatter = Formatter()
    count = 0
    for _, field_name, _, _ in formatter.parse(template):
        if field_name == "":
            count += 1
    logger.debug(f"Template '{template}' has {count} positional fields")

    return count


def _render_template(template: str, **format_kwargs: Any) -> str:
    """Render ``template`` while preserving literal ``{}`` placeholders.

    Older datasets relied on bare ``{}`` placeholders to denote values that
    would be filled later when consumers supplied country names.  When the
    helpers were introduced we started rendering templates using keyword
    arguments, which triggered ``IndexError`` exceptions for those legacy
    placeholders.  The helper counts positional fields and injects literal
    ``"{}"`` strings so the placeholders survive the formatting step.
    """

    positional_count = _count_positional_fields(template)
    positional_args: tuple[str, ...] = ("{}",) * positional_count
    return template.format(*positional_args, **format_kwargs)


def extend_with_templates(
    target: MutableMapping[str, str],
    templates: Mapping[str, str],
    **format_kwargs: Any,
) -> None:
    """Populate ``target`` using ``templates`` and ``format_kwargs``.

    Args:
        target: Dictionary that receives the rendered templates.
        templates: Mapping of key template to label template.
        **format_kwargs: Parameters available during ``str.format``
            expansion for both template strings.
    """

    for key_template, value_template in templates.items():
        rendered_key = _render_template(key_template, **format_kwargs)
        rendered_value = _render_template(value_template, **format_kwargs)
        target[rendered_key] = rendered_value


def extend_with_year_templates(
    target: MutableMapping[str, str],
    templates: Mapping[str, str],
    *,
    years: Iterable[int] | None = None,
    **format_kwargs: Any,
) -> None:
    """Render ``templates`` for every year and update ``target``.

    Args:
        target: Dictionary that receives all rendered templates.
        templates: Mapping of key template to label template.
        years: Optional iterable of integer years.  When omitted the
            project wide :data:`YEARS` constant is used.
        **format_kwargs: Extra formatting arguments used for the template
            expansion.
    """

    for year in years or YEARS:
        extend_with_templates(target, templates, year=year, **format_kwargs)


__all__ = ["YEARS", "extend_with_templates", "extend_with_year_templates"]



#!/usr/bin/python3
"""
Utilities for assembling singer-related gendered job labels.
"""

from __future__ import annotations

import sys
from typing import Dict, Mapping

from ...helps import len_print
from ..utils.json_dir import open_json, open_json_file
from .jobs_defs import GenderedLabel, GenderedLabelMap

# ---------------------------------------------------------------------------
# Helper functions


# ---------------------------------------------------------------------------
# Static configuration


FILMS_TYPE: Mapping[str, GenderedLabel] = {
    "film": {"males": "أفلام", "females": "أفلام"},
    "silent film": {"males": "أفلام صامتة", "females": "أفلام صامتة"},
    "pornographic film": {"males": "أفلام إباحية", "females": "أفلام إباحية"},
    "television": {"males": "تلفزيون", "females": "تلفزيون"},
    "musical theatre": {"males": "مسرحيات موسيقية", "females": "مسرحيات موسيقية"},
    "stage": {"males": "مسرح", "females": "مسرح"},
    "radio": {"males": "راديو", "females": "راديو"},
    "voice": {"males": "أداء صوتي", "females": "أداء صوتي"},
    "video game": {"males": "ألعاب فيديو", "females": "ألعاب فيديو"},
}

"""Seed mapping of singer categories to their Arabic descriptions."""


SINGERS_AFTER_ROLES: Mapping[str, GenderedLabel] = {
    "musicians": {"males": "موسيقيو", "females": "موسيقيات"},
    "singers": {"males": "مغنو", "females": "مغنيات"},
    "educators": {"males": "معلمو", "females": "معلمات"},
    "historians": {"males": "مؤرخو", "females": "مؤرخات"},
    "bloggers": {"males": "مدونو", "females": "مدونات"},
    "drummers": {"males": "طبالو", "females": "طبالات"},
    "authors": {"males": "مؤلفو", "females": "مؤلفات"},
    "journalists": {"males": "صحفيو", "females": "صحفيات"},
    "composers": {"males": "ملحنو", "females": "ملحنات"},
    "record producers": {"males": "منتجو تسجيلات", "females": "منتجات تسجيلات"},
    "singer-songwriters": {"males": "مغنون وكتاب أغاني", "females": "مغنيات وكاتبات أغاني"},
    "songwriters": {"males": "كتاب أغان", "females": "كاتبات أغان"},
    "critics": {"males": "نقاد", "females": "ناقدات"},
    "violinists": {"males": "عازفو كمان", "females": "عازفات كمان"},
    "trumpeters": {"males": "عازفو بوق", "females": "عازفات بوق"},
    "bassoonists": {"males": "عازفو باسون", "females": "عازفات باسون"},
    "trombonists": {"males": "عازفو ترومبون", "females": "عازفات ترومبون"},
    "flautists": {"males": "عازفو فولت", "females": "عازفات فولت"},
    "writers": {"males": "كتاب", "females": "كاتبات"},
    "guitarists": {"males": "عازفو قيثارة", "females": "عازفات قيثارة"},
    "pianists": {"males": "عازفو بيانو", "females": "عازفات بيانو"},
    "saxophonists": {"males": "عازفو سكسفون", "females": "عازفات سكسفون"},
    "bandleaders": {"males": "قادة فرق", "females": "قائدات فرق"},
    "cheerleaders": {"males": "قادة تشجيع", "females": "قائدات تشجيع"},
}

"""Roles that can be combined with the singer categories above."""

NON_FICTION_BASE_TOPICS: Mapping[str, GenderedLabel] = {
    "non-fiction": {"males": "غير روائيين", "females": "غير روائيات"},
    "non-fiction environmental": {
        "males": "بيئة غير روائيين",
        "females": "بيئة غير روائيات",
    },
    "detective": {"males": "بوليسيون", "females": "بوليسيات"},
    "military": {"males": "عسكريون", "females": "عسكريات"},
    "nautical": {"males": "بحريون", "females": "بحريات"},
    "maritime": {"males": "بحريون", "females": "بحريات"},
}

"""Seed topics that receive dedicated non-fiction role variants."""


NON_FICTION_ADDITIONAL_TOPICS: Mapping[str, str] = {
    "environmental": "بيئة",
    "economics": "إقتصاد",
    "hymn": "ترانيم",
    "architecture": "عمارة",
    "magazine": "مجلات",
    "medical": "طب",
    "organized crime": "جريمة منظمة",
    "crime": "جريمة",
    "legal": "قانون",
    "business": "أعمال تجارية",
    "nature": "طبيعة",
    "political": "سياسة",
    "art": "فن",
    "food": "طعام",
    "travel": "سفر",
    "spiritual": "روحانية",
    "arts": "فنون",
    "social sciences": "علوم اجتماعية",
    "music": "موسيقى",
    "science": "علم",
    "technology": "تقانة",
    "comedy": "كوميدي",
}

"""Topics duplicated for both masculine and feminine forms when generating variants."""


# ---------------------------------------------------------------------------
# Aggregate data assembly

SINGERS_TAB: Dict[str, str] = open_json("jobs/singers_tab.json") or {}

SINGER_CATEGORY_LABELS: Dict[str, str] = SINGERS_TAB
"""Complete mapping of singer categories combining static and JSON sources."""

NON_FICTION_TOPICS: Dict[str, GenderedLabel] = dict(NON_FICTION_BASE_TOPICS)

for topic_key, topic_label in NON_FICTION_ADDITIONAL_TOPICS.items():
    NON_FICTION_TOPICS[topic_key] = {"males": topic_label, "females": topic_label}

"""Expanded non-fiction topics covering both static and dynamically generated entries."""

MEN_WOMENS_SINGERS_BASED: GenderedLabelMap = open_json("jobs/jobs_Men_Womens_Singers.json") or {}

MEN_WOMENS_SINGERS = open_json_file("MEN_WOMENS_SINGERS_found.json")

len_print.data_len(
    "jobs_singers.py",
    {
        "MEN_WOMENS_SINGERS_BASED": MEN_WOMENS_SINGERS_BASED,
        "FILMS_TYPE": FILMS_TYPE,
        "NON_FICTION_BASE_TOPICS": NON_FICTION_BASE_TOPICS,
        "NON_FICTION_TOPICS": NON_FICTION_TOPICS,
        "SINGER_CATEGORY_LABELS": SINGER_CATEGORY_LABELS,
        "SINGERS_AFTER_ROLES": SINGERS_AFTER_ROLES,
        "MEN_WOMENS_SINGERS": MEN_WOMENS_SINGERS,
        "SINGERS_TAB": SINGERS_TAB,
    },
)

__all__ = [
    "MEN_WOMENS_SINGERS_BASED",
    "FILMS_TYPE",
    "MEN_WOMENS_SINGERS",
    "SINGERS_TAB",
]



#!/usr/bin/python3
"""
Resolves category labels for religious groups combined with nationalities.
TODO: write code
"""

import functools

formatted_data = {
    # "Category:Indonesian women singers": "تصنيف:مغنيات إندونيسيات",
    "{en} singers": "مغنون {males}",
    "{en} women singers": "مغنيات {females}",
}


def resolve_nats_jobs(category: str) -> str:
    """
    Resolves the Arabic label for a category string that combines a religious group and a nationality.
    Args:
        category: The input category string.
    Returns:
        The translated Arabic category label, or an empty string if no match is found.
    """
    return ""



"""

"""
import json
import sys
import time
from pathlib import Path

from tqdm import tqdm

if _Dir := Path(__file__).parent.parent:
    sys.path.append(str(Path(__file__).parent))
    sys.path.append(str(_Dir))

from ArWikiCats import batch_resolve_labels, print_memory


def compare_and_export_labels(data, name, remove_ar_prefix=False):
    time_start = time.perf_counter()

    result = batch_resolve_labels(tqdm(list(data.keys())))
    labels = result.labels

    no_labels = {x: data.get(x) for x in result.no_labels}

    print(f"total: {len(data)}")
    print(f"labels: {len(labels)}")
    print(f"no_labels: {len(no_labels)}")

    time_diff = time.perf_counter() - time_start
    print(f"total time: {time_diff} seconds")
    print_memory()

    same = {}
    diff = {
        "old": {},
        "new": {},
    }
    for key, value in labels.items():
        value = value.replace("تصنيف:", "") if remove_ar_prefix else value
        data_value = data.get(key, "").replace("تصنيف:", "") if remove_ar_prefix else data.get(key, "")

        if value == data_value:
            same[key] = value
        else:
            diff["new"][key] = value
            diff["old"][key] = data_value

    print(f"same: {len(same)}, diff: {len(diff['old'])}")

    output_dir = Path(__file__).parent
    if diff["new"]:
        with open(output_dir / f"{name}_diff.json", "w", encoding="utf-8") as f:
            json.dump(diff, f, ensure_ascii=False, indent=4)

    if no_labels:
        with open(output_dir / f"{name}_no_labels.json", "w", encoding="utf-8") as f:
            json.dump(no_labels, f, ensure_ascii=False, indent=4)

    if diff["new"] or no_labels:
        with open(output_dir / f"{name}_same.json", "w", encoding="utf-8") as f:
            json.dump(same, f, ensure_ascii=False, indent=4)



#!/usr/bin/python3
"""

countries_names.py use only countries names without nationalities
countries_names_v2.py use countries names with nationalities

"""
import functools

from ...helps import logger
from ...translations import countries_nat_en_key
from ...translations_formats import FormatDataV2
from ..nationalities_resolvers.data import country_names_and_nats_data
from .countries_names_data import formatted_data_en_ar_only

countries_nat_en_key_example = {
    "yemen": {
        "ar": "اليمن",
        "en": "Yemen",
        "male": "يمني",
        "female": "يمنية",
        "the_male": "اليمني",
        "the_female": "اليمنية",
    }
}

new_data: dict[str, str] = {
    # the_female
    "dependent territories of {en}": "أقاليم ما وراء البحار {the_female}",
    "supreme court of {en}": "المحكمة العليا {the_female}",
}

# NOTE: patterns with only en-ar should be in formatted_data_en_ar_only countries_names.py to handle countries without gender details
# NOTE: patterns with only en-ar-time should be in COUNTRY_YEAR_DATA to handle countries-time without gender details

all_data: dict[str, str] = {
    # the_female
    "{en} cup-of-nations": "كأس الأمم {the_female}",
    "{en} cup of nations": "كأس الأمم {the_female}",
    "women's {en} cup of nations": "كأس الأمم {the_female} للسيدات",
    "women's {en} cup-of-nations": "كأس الأمم {the_female} للسيدات",
    "{en} cup-of-nations players": "لاعبو كأس الأمم {the_female}",
    "{en} cup of nations players": "لاعبو كأس الأمم {the_female}",
    "women's {en} cup of nations players": "لاعبات كأس الأمم {the_female} للسيدات",
    "women's {en} cup-of-nations players": "لاعبات كأس الأمم {the_female} للسيدات",
    # males - en_is_P17_ar_is_mens
    "{en} political leaders": "قادة سياسيون {males}",
    "{en} political leader": "قادة سياسيون {males}",
    "{en} government officials": "مسؤولون حكوميون {males}",
    # female - military_format_women_without_al_from_end
    # Category:Unmanned_aerial_vehicles_of_Jordan > طائرات بدون طيار أردنية
    "unmanned military aircraft-of {en}": "طائرات عسكرية بدون طيار {female}",
    "unmanned military aircraft of {en}": "طائرات عسكرية بدون طيار {female}",
    "unmanned aerial vehicles-of {en}": "طائرات بدون طيار {female}",
    "unmanned aerial vehicles of {en}": "طائرات بدون طيار {female}",
}

all_data.update(country_names_and_nats_data)


@functools.lru_cache(maxsize=1)
def _load_bot() -> FormatDataV2:
    nats_data = {x: v for x, v in countries_nat_en_key.items() if v.get("ar")}
    formatted_data = all_data | new_data | formatted_data_en_ar_only

    return FormatDataV2(
        formatted_data=formatted_data,
        data_list=nats_data,
        key_placeholder="{en}",
        text_before="the ",
    )


@functools.lru_cache(maxsize=10000)
def resolve_by_countries_names_v2(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_by_countries_names_v2: {category=}")

    nat_bot = _load_bot()
    result = nat_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_by_countries_names_v2: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_by_countries_names_v2",
]



"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.resolve_languages import resolve_languages_labels

test_data = {
    "Category:Persian-language singers of Tajikistan": "تصنيف:مغنون باللغة الفارسية في طاجيكستان",
    "Category:2010 Tamil-language television seasons": "تصنيف:مواسم تلفزيونية باللغة التاميلية 2010",
    "Category:Urdu-language fiction": "تصنيف:خيالية باللغة الأردية",
    "Category:Cantonese-language singers": "تصنيف:مغنون باللغة الكانتونية",
    "Category:Yiddish-language singers of Austria": "تصنيف:مغنون باللغة اليديشية في النمسا",
    "Category:Yiddish-language singers of Russia": "تصنيف:مغنون باللغة اليديشية في روسيا",
    "Category:Tajik-language singers of Russia": "تصنيف:مغنون باللغة الطاجيكية في روسيا",
    "Category:Persian-language singers of Russia": "تصنيف:مغنون باللغة الفارسية في روسيا",
    "Category:Hebrew-language singers of Russia": "تصنيف:مغنون باللغة العبرية في روسيا",
    "Category:German-language singers of Russia": "تصنيف:مغنون باللغة الألمانية في روسيا",
    "Category:Azerbaijani-language singers of Russia": "تصنيف:مغنون باللغة الأذربيجانية في روسيا",
    "category:urdu-language non-fiction writers": "تصنيف:كتاب غير روائيين باللغة الأردية",
    "bengali-language romantic comedy films": "أفلام كوميدية رومانسية باللغة البنغالية",
    "cantonese-language speculative fiction films": "أفلام خيالية تأملية باللغة الكانتونية",
    "abkhazian-language writers": "كتاب باللغة الأبخازية",
}


@pytest.mark.parametrize("input_category, expected_output", test_data.items())
@pytest.mark.skip2
def test_resolve_languages_labels(input_category: str, expected_output: str) -> None:
    result = resolve_languages_labels(input_category)
    assert result == expected_output



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test_no_labels

from ArWikiCats import resolve_arabic_category_label

data_0 = {
    "Category:American science and technology awards": "",
    "Category:Appropriate technology": "",
    "Category:Assistive technology": "",
    "Category:Banking technology": "",
    "Category:British science and technology awards": "",
    "Category:Building technology": "",
    "Category:Canadian science and technology awards": "",
    "Category:Cleanroom technology": "",
    "Category:Digital technology": "",
    "Category:Display technology": "",
    "Category:Display technology companies": "",
    "Category:DNA nanotechnology": "",
    "Category:Drilling technology": "",
    "Category:Dutch science and technology awards": "",
    "Category:Electronic paper technology": "",
    "Category:European Union technology policy": "",
    "Category:Fiction about nanotechnology": "",
    "Category:Fictional technology": "",
    "Category:Film and video technology templates": "",
    "Category:Financial technology": "",
    "Category:Flavor technology": "",
    "Category:Food technology": "",
    "Category:French science and technology awards": "",
    "Category:German science and technology awards": "",
    "Category:High-technology business districts": "",
    "Category:Hypothetical technology": "",
    "Category:Indian science and technology awards": "",
    "Category:Information technology companies": "",
    "Category:Information technology companies by country": "",
    "Category:Information technology places": "",
    "Category:Internet technology companies": "",
    "Category:Missile technology": "",
    "Category:Nanotechnology": "",
    "Category:Nanotechnology and the environment": "",
    "Category:Nanotechnology companies": "",
    "Category:Nanotechnology templates": "",
    "Category:Neurotechnology": "",
    "Category:Nuclear technology companies of the United States": "",
    "Category:Nuclear technology organizations of Japan": "",
    "Category:Power station technology": "",
    "Category:Radio technology templates": "",
    "Category:Russian science and technology awards": "",
    "Category:Science, technology, and engineering WikiProjects": "",
    "Category:Science and technology in Prayagraj": "",
    "Category:Sound production technology": "",
    "Category:Sound recording technology": "",
    "Category:Swedish science and technology awards": "",
    "Category:Travel technology": "",
    "Category:Waste treatment technology": "",
    "Category:Water technology": "",
    "Category:Web technology": "",
}

data_fast = {
    "Category:American technology journalists": "تصنيف:صحفيو تقانة أمريكيون",
    "Category:American technology writers": "تصنيف:كتاب تقانة أمريكيون",
    "Category:Australian technology writers": "تصنيف:كتاب تقانة أستراليون",
    "Category:Austrian technology writers": "تصنيف:كتاب تقانة نمساويون",
    "Category:British technology journalists": "تصنيف:صحفيو تقانة بريطانيون",
    "Category:Chinese technology writers": "تصنيف:كتاب تقانة صينيون",
    "Category:Environmental technology": "تصنيف:تقانة بيئية",
    "Category:Films by technology": "تصنيف:أفلام حسب التقانة",
    "Category:French technology writers": "تصنيف:كتاب تقانة فرنسيون",
    "Category:Greek technology writers": "تصنيف:كتاب تقانة يونانيون",
    "Category:Information technology by country": "تصنيف:تقانة المعلومات حسب البلد",
    "Category:Information technology companies of Africa": "تصنيف:شركات تقانة المعلومات في إفريقيا",
    "Category:Information technology companies of Africa by country": "تصنيف:شركات تقانة المعلومات في إفريقيا حسب البلد",
    "Category:Information technology companies of Australia": "تصنيف:شركات تقانة المعلومات في أستراليا",
    "Category:Information technology companies of Egypt": "تصنيف:شركات تقانة المعلومات في مصر",
    "Category:Information technology companies of France": "تصنيف:شركات تقانة المعلومات في فرنسا",
    "Category:Information technology companies of India": "تصنيف:شركات تقانة المعلومات في الهند",
    "Category:Information technology companies of Japan": "تصنيف:شركات تقانة المعلومات في اليابان",
    "Category:Information technology companies of Russia": "تصنيف:شركات تقانة المعلومات في روسيا",
    "Category:Information technology companies of South Korea": "تصنيف:شركات تقانة المعلومات في كوريا الجنوبية",
    "Category:Information technology companies of the United States": "تصنيف:شركات تقانة المعلومات في الولايات المتحدة",
    "Category:Information technology in Australia": "تصنيف:تقانة المعلومات في أستراليا",
    "Category:Information technology in Brazil": "تصنيف:تقانة المعلومات في البرازيل",
    "Category:Information technology in Bulgaria": "تصنيف:تقانة المعلومات في بلغاريا",
    "Category:Information technology in Canada": "تصنيف:تقانة المعلومات في كندا",
    "Category:Information technology in Chile": "تصنيف:تقانة المعلومات في تشيلي",
    "Category:Information technology in China": "تصنيف:تقانة المعلومات في الصين",
    "Category:Information technology in Denmark": "تصنيف:تقانة المعلومات في الدنمارك",
    "Category:Information technology in France": "تصنيف:تقانة المعلومات في فرنسا",
    "Category:Information technology in Germany": "تصنيف:تقانة المعلومات في ألمانيا",
    "Category:Information technology in India": "تصنيف:تقانة المعلومات في الهند",
    "Category:Information technology in Israel": "تصنيف:تقانة المعلومات في إسرائيل",
    "Category:Information technology in Japan": "تصنيف:تقانة المعلومات في اليابان",
    "Category:Information technology in Kazakhstan": "تصنيف:تقانة المعلومات في كازاخستان",
    "Category:Information technology in Mali": "تصنيف:تقانة المعلومات في مالي",
    "Category:Information technology in Mauritius": "تصنيف:تقانة المعلومات في موريشيوس",
    "Category:Information technology in Mexico": "تصنيف:تقانة المعلومات في المكسيك",
    "Category:Information technology in New Zealand": "تصنيف:تقانة المعلومات في نيوزيلندا",
    "Category:Information technology in Nigeria": "تصنيف:تقانة المعلومات في نيجيريا",
    "Category:Information technology in North Korea": "تصنيف:تقانة المعلومات في كوريا الشمالية",
    "Category:Information technology in Norway": "تصنيف:تقانة المعلومات في النرويج",
    "Category:Information technology in Pakistan": "تصنيف:تقانة المعلومات في باكستان",
    "Category:Information technology in Russia": "تصنيف:تقانة المعلومات في روسيا",
    "Category:Information technology in South Korea": "تصنيف:تقانة المعلومات في كوريا الجنوبية",
    "Category:Information technology in Sri Lanka": "تصنيف:تقانة المعلومات في سريلانكا",
    "Category:Information technology in Sweden": "تصنيف:تقانة المعلومات في السويد",
    "Category:Information technology in Switzerland": "تصنيف:تقانة المعلومات في سويسرا",
    "Category:Information technology in Syria": "تصنيف:تقانة المعلومات في سوريا",
    "Category:Information technology in Thailand": "تصنيف:تقانة المعلومات في تايلاند",
    "Category:Information technology in the Netherlands": "تصنيف:تقانة المعلومات في هولندا",
    "Category:Information technology in the Philippines": "تصنيف:تقانة المعلومات في الفلبين",
    "Category:Information technology in the United Arab Emirates": "تصنيف:تقانة المعلومات في الإمارات العربية المتحدة",
    "Category:Information technology in the United Kingdom": "تصنيف:تقانة المعلومات في المملكة المتحدة",
    "Category:Information technology in the United States": "تصنيف:تقانة المعلومات في الولايات المتحدة",
    "Category:Information technology in Tokelau": "تصنيف:تقانة المعلومات في توكيلاو",
    "Category:Information technology in Ukraine": "تصنيف:تقانة المعلومات في أوكرانيا",
    "Category:Irish technology writers": "تصنيف:كتاب تقانة أيرلنديون",
    "Category:Military technology": "تصنيف:تقانة عسكرية",
    "Category:Non-profit technology": "تصنيف:تقانة العمل الخيري",
    "Category:Nuclear technology in Argentina": "تصنيف:تقانة نووية في الأرجنتين",
    "Category:Nuclear technology in Australia": "تصنيف:تقانة نووية في أستراليا",
    "Category:Nuclear technology in Austria": "تصنيف:تقانة نووية في النمسا",
    "Category:Nuclear technology in Brazil": "تصنيف:تقانة نووية في البرازيل",
    "Category:Nuclear technology in China": "تصنيف:تقانة نووية في الصين",
    "Category:Nuclear technology in Denmark": "تصنيف:تقانة نووية في الدنمارك",
    "Category:Nuclear technology in Egypt": "تصنيف:تقانة نووية في مصر",
    "Category:Nuclear technology in Finland": "تصنيف:تقانة نووية في فنلندا",
    "Category:Nuclear technology in France": "تصنيف:تقانة نووية في فرنسا",
    "Category:Nuclear technology in Germany": "تصنيف:تقانة نووية في ألمانيا",
    "Category:Nuclear technology in India": "تصنيف:تقانة نووية في الهند",
    "Category:Nuclear technology in Iran": "تصنيف:تقانة نووية في إيران",
    "Category:Nuclear technology in Iraq": "تصنيف:تقانة نووية في العراق",
    "Category:Nuclear technology in Israel": "تصنيف:تقانة نووية في إسرائيل",
    "Category:Nuclear technology in Italy": "تصنيف:تقانة نووية في إيطاليا",
    "Category:Nuclear technology in Japan": "تصنيف:تقانة نووية في اليابان",
    "Category:Nuclear technology in Jordan": "تصنيف:تقانة نووية في الأردن",
    "Category:Nuclear technology in Libya": "تصنيف:تقانة نووية في ليبيا",
    "Category:Nuclear technology in New Zealand": "تصنيف:تقانة نووية في نيوزيلندا",
    "Category:Nuclear technology in North Korea": "تصنيف:تقانة نووية في كوريا الشمالية",
    "Category:Nuclear technology in Pakistan": "تصنيف:تقانة نووية في باكستان",
    "Category:Nuclear technology in Saudi Arabia": "تصنيف:تقانة نووية في السعودية",
    "Category:Nuclear technology in South Korea": "تصنيف:تقانة نووية في كوريا الجنوبية",
    "Category:Nuclear technology in Sweden": "تصنيف:تقانة نووية في السويد",
    "Category:Nuclear technology in Taiwan": "تصنيف:تقانة نووية في تايوان",
    "Category:Nuclear technology in Thailand": "تصنيف:تقانة نووية في تايلاند",
    "Category:Nuclear technology in the Czech Republic": "تصنيف:تقانة نووية في التشيك",
    "Category:Nuclear technology in the Netherlands": "تصنيف:تقانة نووية في هولندا",
    "Category:Nuclear technology in the United Kingdom": "تصنيف:تقانة نووية في المملكة المتحدة",
    "Category:Nuclear technology in the United States": "تصنيف:تقانة نووية في الولايات المتحدة",
    "Category:Nuclear technology in Turkey": "تصنيف:تقانة نووية في تركيا",
    "Category:Nuclear technology in Ukraine": "تصنيف:تقانة نووية في أوكرانيا",
    "Category:Nuclear technology organizations by country": "تصنيف:منظمات تقانة نووية حسب البلد",
    "Category:Pakistani technology writers": "تصنيف:كتاب تقانة باكستانيون",
    "Category:People in information technology": "تصنيف:أشخاص في تقانة المعلومات",
    "Category:Stealth technology": "تصنيف:تقانة التخفي",
    "Category:Video games about nuclear technology": "تصنيف:ألعاب فيديو عن تقانة نووية",
    "Category:Women technology writers": "تصنيف:كاتبات تقانة",
    "Category:Works about technology": "تصنيف:أعمال عن التقانة",
}

data_slow = {
    "Category:Aviation technology": "تصنيف:تقانة طيران",
    "Category:Businesspeople in information technology": "تصنيف:شخصيات أعمال في تقانة المعلومات",
    "Category:Businesspeople in technology": "تصنيف:شخصيات أعمال في التقانة",
    "Category:Defunct technology companies": "تصنيف:شركات تقانة سابقة",
    "Category:Defunct technology companies of the United Kingdom": "تصنيف:شركات تقانة سابقة في المملكة المتحدة",
    "Category:Documentary films about technology": "تصنيف:أفلام وثائقية عن التقانة",
    "Category:Historians of technology": "تصنيف:مؤرخو التقانة",
    "Category:History of science and technology in China": "تصنيف:تاريخ العلوم والتقانة في الصين",
    "Category:History of science and technology in England": "تصنيف:تاريخ العلوم والتقانة في إنجلترا",
    "Category:Information technology in Uruguay": "تصنيف:تقانة المعلومات في أوروغواي",
    "Category:Music technology": "تصنيف:تقانة موسيقية",
    "Category:Nuclear technology by former country": "تصنيف:تقانة نووية حسب البلد السابق",
    "Category:Nuclear technology in Kazakhstan": "تصنيف:تقانة نووية في كازاخستان",
    "Category:Nuclear technology in Russia": "تصنيف:تقانة نووية في روسيا",
    "Category:Nuclear technology in the Soviet Union": "تصنيف:تقانة نووية في الاتحاد السوفيتي",
    "Category:People associated with technology": "تصنيف:أشخاص مرتبطون مع التقانة",
    "Category:Philosophers of technology": "تصنيف:فلاسفة من التقانة",
    "Category:Politics and technology": "تصنيف:السياسة والتقانة",
    "Category:Science and technology by continent": "تصنيف:العلوم والتقانة حسب القارة",
    "Category:Science and technology by country": "تصنيف:العلوم والتقانة حسب البلد",
    "Category:Science and technology by location": "تصنيف:العلوم والتقانة حسب الموقع",
    "Category:Science and technology in Algeria": "تصنيف:العلوم والتقانة في الجزائر",
    "Category:Science and technology in Asia": "تصنيف:العلوم والتقانة في آسيا",
    "Category:Science and technology in Australia": "تصنيف:العلوم والتقانة في أستراليا",
    "Category:Science and technology in Australia by state or territory": "تصنيف:العلوم والتقانة في أستراليا حسب الولاية أو الإقليم",
    "Category:Science and technology in Austria": "تصنيف:العلوم والتقانة في النمسا",
    "Category:Science and technology in Azerbaijan": "تصنيف:العلوم والتقانة في أذربيجان",
    "Category:Science and technology in Bahrain": "تصنيف:العلوم والتقانة في البحرين",
    "Category:Science and technology in Bosnia and Herzegovina": "تصنيف:العلوم والتقانة في البوسنة والهرسك",
    "Category:Science and technology in Brazil": "تصنيف:العلوم والتقانة في البرازيل",
    "Category:Science and technology in California": "تصنيف:العلوم والتقانة في كاليفورنيا",
    "Category:Science and technology in Cambridgeshire": "تصنيف:العلوم والتقانة في كامبريدجشير",
    "Category:Science and technology in Canada": "تصنيف:العلوم والتقانة في كندا",
    "Category:Science and technology in China": "تصنيف:العلوم والتقانة في الصين",
    "Category:Science and technology in Colombia": "تصنيف:العلوم والتقانة في كولومبيا",
    "Category:Science and technology in Denmark": "تصنيف:العلوم والتقانة في الدنمارك",
    "Category:Science and technology in Devon": "تصنيف:العلوم والتقانة في ديفون",
    "Category:Science and technology in East Asia": "تصنيف:العلوم والتقانة في شرق آسيا",
    "Category:Science and technology in Egypt": "تصنيف:العلوم والتقانة في مصر",
    "Category:Science and technology in El Salvador": "تصنيف:العلوم والتقانة في السلفادور",
    "Category:Science and technology in England": "تصنيف:العلوم والتقانة في إنجلترا",
    "Category:Science and technology in Essex": "تصنيف:العلوم والتقانة في إسكس",
    "Category:Science and technology in Estonia": "تصنيف:العلوم والتقانة في إستونيا",
    "Category:Science and technology in Finland": "تصنيف:العلوم والتقانة في فنلندا",
    "Category:Science and technology in France": "تصنيف:العلوم والتقانة في فرنسا",
    "Category:Science and technology in Germany": "تصنيف:العلوم والتقانة في ألمانيا",
    "Category:Science and technology in Greater Manchester": "تصنيف:العلوم والتقانة في مانشستر الكبرى",
    "Category:Science and technology in Hampshire": "تصنيف:العلوم والتقانة في هامبشاير",
    "Category:Science and technology in Hertfordshire": "تصنيف:العلوم والتقانة في هيرتفوردشاير",
    "Category:Science and technology in India": "تصنيف:العلوم والتقانة في الهند",
    "Category:Science and technology in Iran": "تصنيف:العلوم والتقانة في إيران",
    "Category:Science and technology in Iraq": "تصنيف:العلوم والتقانة في العراق",
    "Category:Science and technology in Israel": "تصنيف:العلوم والتقانة في إسرائيل",
    "Category:Science and technology in Italy": "تصنيف:العلوم والتقانة في إيطاليا",
    "Category:Science and technology in Japan": "تصنيف:العلوم والتقانة في اليابان",
    "Category:Science and technology in Jordan": "تصنيف:العلوم والتقانة في الأردن",
    "Category:Science and technology in Korea": "تصنيف:العلوم والتقانة في كوريا",
    "Category:Science and technology in Kuwait": "تصنيف:العلوم والتقانة في الكويت",
    "Category:Science and technology in Lebanon": "تصنيف:العلوم والتقانة في لبنان",
    "Category:Science and technology in Leicestershire": "تصنيف:العلوم والتقانة في ليسترشير",
    "Category:Science and technology in London": "تصنيف:العلوم والتقانة في لندن",
    "Category:Science and technology in Merseyside": "تصنيف:العلوم والتقانة في مرزيسايد",
    "Category:Science and technology in Morocco": "تصنيف:العلوم والتقانة في المغرب",
    "Category:Science and technology in New South Wales": "تصنيف:العلوم والتقانة في نيوساوث ويلز",
    "Category:Science and technology in New York (state)": "تصنيف:العلوم والتقانة في ولاية نيويورك",
    "Category:Science and technology in North America": "تصنيف:العلوم والتقانة في أمريكا الشمالية",
    "Category:Science and technology in North Korea": "تصنيف:العلوم والتقانة في كوريا الشمالية",
    "Category:Science and technology in Norway": "تصنيف:العلوم والتقانة في النرويج",
    "Category:Science and technology in Oceania": "تصنيف:العلوم والتقانة في أوقيانوسيا",
    "Category:Science and technology in Oxfordshire": "تصنيف:العلوم والتقانة في أوكسفوردشاير",
    "Category:Science and technology in Pakistan": "تصنيف:العلوم والتقانة في باكستان",
    "Category:Science and technology in Palestine": "تصنيف:العلوم والتقانة في فلسطين",
    "Category:Science and technology in Poland": "تصنيف:العلوم والتقانة في بولندا",
    "Category:Science and technology in Qatar": "تصنيف:العلوم والتقانة في قطر",
    "Category:Science and technology in Russia": "تصنيف:العلوم والتقانة في روسيا",
    "Category:Science and technology in Saudi Arabia": "تصنيف:العلوم والتقانة في السعودية",
    "Category:Science and technology in Scotland": "تصنيف:العلوم والتقانة في إسكتلندا",
    "Category:Science and technology in Sierra Leone": "تصنيف:العلوم والتقانة في سيراليون",
    "Category:Science and technology in Slovenia": "تصنيف:العلوم والتقانة في سلوفينيا",
    "Category:Science and technology in Somerset": "تصنيف:العلوم والتقانة في سومرست",
    "Category:Science and technology in South America": "تصنيف:العلوم والتقانة في أمريكا الجنوبية",
    "Category:Science and technology in South Korea": "تصنيف:العلوم والتقانة في كوريا الجنوبية",
    "Category:Science and technology in Spain": "تصنيف:العلوم والتقانة في إسبانيا",
    "Category:Science and technology in Sudan": "تصنيف:العلوم والتقانة في السودان",
    "Category:Science and technology in Sweden": "تصنيف:العلوم والتقانة في السويد",
    "Category:Science and technology in Switzerland": "تصنيف:العلوم والتقانة في سويسرا",
    "Category:Science and technology in Syria": "تصنيف:العلوم والتقانة في سوريا",
    "Category:Science and technology in the Caribbean": "تصنيف:العلوم والتقانة في الكاريبي",
    "Category:Science and technology in the East Riding of Yorkshire": "تصنيف:العلوم والتقانة في إيست رايدينج أوف يوركشير",
    "Category:Science and technology in the Netherlands": "تصنيف:العلوم والتقانة في هولندا",
    "Category:Science and technology in the Ottoman Empire": "تصنيف:العلوم والتقانة في الدولة العثمانية",
    "Category:Science and technology in the San Francisco Bay Area": "تصنيف:العلوم والتقانة في منطقة خليج سان فرانسيسكو",
    "Category:Science and technology in the Soviet Union": "تصنيف:العلوم والتقانة في الاتحاد السوفيتي",
    "Category:Science and technology in the United Arab Emirates": "تصنيف:العلوم والتقانة في الإمارات العربية المتحدة",
    "Category:Science and technology in the United Kingdom": "تصنيف:العلوم والتقانة في المملكة المتحدة",
    "Category:Science and technology in the United States": "تصنيف:العلوم والتقانة في الولايات المتحدة",
    "Category:Science and technology in the United States by state or territory": "تصنيف:العلوم والتقانة في الولايات المتحدة حسب الولاية أو الإقليم",
    "Category:Science and technology in the West Midlands (county)": "تصنيف:العلوم والتقانة في مقاطعة ميدلاند الغربية",
    "Category:Science and technology in Tunisia": "تصنيف:العلوم والتقانة في تونس",
    "Category:Science and technology in Uruguay": "تصنيف:العلوم والتقانة في أوروغواي",
    "Category:Science and technology in Wales": "تصنيف:العلوم والتقانة في ويلز",
    "Category:Science and technology in Warwickshire": "تصنيف:العلوم والتقانة في وركشير",
    "Category:Science and technology in West Sussex": "تصنيف:العلوم والتقانة في غرب ساسكس",
    "Category:Science and technology in West Yorkshire": "تصنيف:العلوم والتقانة في غرب يوركشاير",
    "Category:Science and technology in Yemen": "تصنيف:العلوم والتقانة في اليمن",
    "Category:Sports technology": "تصنيف:تقانة رياضية",
}

to_test = [
    ("test_technology_1", data_fast),
    ("test_technology_slow", data_slow),
]


@pytest.mark.parametrize("category, expected", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_technology_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data_slow.items(), ids=data_slow.keys())
@pytest.mark.slow
def test_technology_slow(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result, no_labels = one_dump_test_no_labels(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, just_dump=True)
    assert (
        diff_result == expected
    ), f"Differences found: {len(diff_result):,}, len all :{len(data):,}, len no_labels: {len(no_labels):,}"
